@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command.tcl
-#  Last change:  7 October 2004
+#  Last change:  5 April 2006
 #
 
 # this file is only source-ed in command-line mode (even if the graphical
@@ -40,8 +40,11 @@ proc ExecCommand {} {
     # execute command from command line
     # return 0 on success, 1 on error, "wait" to loop, "-0" to quit fast
     global COMMAND CMDLINE NoImgLib GSHPVersion RealTimeLogAnim PVTState \
-	 PVTDumping RealTimeGettingFix MESS
+	 PVTDumping RealTimeGettingFix MESS GPSProtocol
 
+    if { [set prot $COMMAND(prot)] != "" } {
+	set GPSProtocol $prot
+    }
     switch $COMMAND(name) {
 	checkconn {
 	    # "is connected" command
@@ -108,6 +111,9 @@ proc ExecCommand {} {
 	    set PVTState on
 	    return wait
 	}
+	getalmanac {
+	    if { [CmdGetAlmanacFails $COMMAND(path)] } { return 1 }
+	}
 	starttravel {
 	    # enter graphical mode
 	    set CMDLINE 0
@@ -221,8 +227,8 @@ proc ExecGPSConnectFail {args} {
     # return 1 on error, 0 on success
     global GPSOpResult
 
-    if { $args == 0 } {
-       if { [GPSConnection] == 0 } { return 1 }
+    if { $args == "" } {
+       if { [GPSConnection Ignore Ignore] == 0 } { return 1 }
     } elseif { [GPSConnection [lindex $args 0] [lindex $args 1]] == 0 } {
 	return 1
     }
@@ -232,15 +238,10 @@ proc ExecGPSConnectFail {args} {
 
 proc CmdCantStartRTimeLog {connproc errorproc} {
     # return 0 on success, 1 on error
-    global COMMAND RECPROTS GPSREC GPSProtocol
+    global COMMAND GPSProtocol
 
-    if { [set prot $COMMAND(prot)] == "" } {
-	set prot $GPSProtocol
-    } else {
-	set GPSProtocol $prot
-    }
     # this depends on the Garmin variant...
-    if { $prot == "garmin" && \
+    if { [string first "garmin" $GPSProtocol] == 0 && \
 	     [ExecGPSConnectFail $connproc $errorproc] } { return 1 }
     if { ! [StartRealTimeLog $COMMAND(interv)] } { return 1 }
     return 0
@@ -260,6 +261,19 @@ proc CmdGetFails {types} {
     return 0
 }
 
+proc CmdGetAlmanacFails {path} {
+    # get almanac and print it to file
+    # return 0 on success
+    global ALDataTxt
+
+    if { [CmdGetFails AL] || [set f [CmdOpenFile $path out]] == -1 } {
+	return 1
+    }
+    puts $f $ALDataTxt
+    close $f
+    return 0
+}
+
 proc CmdPutFails {types} {
     # put items of given $types
     # return 0 on success
