@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: command_parse.tcl
-#  Last change:  6 October 2004
+#  Last change:  5 April 2006
 #
 
 # this file is only source-ed in command-line mode
@@ -34,7 +34,7 @@ set COMMAND(USAGE) {Usage: gpsman [PREFIXES] COMMAND [ARGS]
     -log          produce a log file of serial communication
     -rec Garmin | Lowrance | Magellan     brand of receiver (only Garmin works)
     -prefs PATH   path to preferences file
-    -prot Garmin | NMEA | SText | simul   receiver protocol
+    -prot Garmin | Garmin_USB | NMEA | SText | simul   receiver protocol
   COMMANDS [ARGS]
     is available | connected
     show help | version | formats | protocols | projections | datums | transfs
@@ -45,6 +45,7 @@ set COMMAND(USAGE) {Usage: gpsman [PREFIXES] COMMAND [ARGS]
               OUT-FORMAT [OUT-PARAMS] [OUT-TYPES] OUT-PATH
     getrtimelog PATH [INTERVAL]
     getfix PATH [TIMEOUT]
+    getalmanac PATH
     project LATD LONGD DATUM PROJECTION [PARAMS]
             (no PREFIXES; DATUM used for projection if PARAMS do not give one)
     georef IMGPATH TRANSF LATD LONGD LATD LONGD [LATD LONGD] DATUM \
@@ -135,10 +136,14 @@ proc BadCommandLine {} {
     }
 
     set argv [lreplace $argv 0 0]
+    set nargs [llength $argv]
     switch -- $cmd {
 	is {
 	    switch -- [lindex $argv 0] {
-		available { return "-0" }
+		available {
+		    set COMMAND(name) available
+		    return "-0"
+		}
 		connected {
 		    # for the time being this is only supported for
 		    #  Garmin receivers
@@ -170,7 +175,7 @@ proc BadCommandLine {} {
 	    if { $GPSREC != "Garmin" } { return 1 }
 	    foreach "in_ts tail" [CmdParseTypes $argv] {}
 	    if { [llength $tail] < 2 || \
-		    [set in_ts [CmdRecTypes $in_ts]] == "" } {
+		    [set in_ts [CmdRecTypes get $in_ts]] == "" } {
 		return 1
 	    }
 	    set fmt [lindex $tail 0]
@@ -201,7 +206,7 @@ proc BadCommandLine {} {
 	    foreach "out_ts tail" [CmdParseTypes [lreplace $tail 0 0]] {}
 	    if { $out_ts == "" } { set out_ts $COMMAND(filetypes) }
 	    if { $tail != "" || \
-		    [set out_ts [CmdRecTypes $out_ts]] == "" || \
+		    [set out_ts [CmdRecTypes put $out_ts]] == "" || \
 		    [CmdIncompatibleTypes $COMMAND(filetypes) $out_ts] } {
 		return 1
 	    }
@@ -210,7 +215,7 @@ proc BadCommandLine {} {
 	translate {
 	    # IN-FORMAT [IN-PARAMS] [IN-TYPES] IN-PATH OUT-FORMAT \
             #    [OUT-PARAMS] [OUT-TYPES] OUT-PATH
-	    if { [llength $argv] < 4 } { return 1 }
+	    if { $nargs < 4 } { return 1 }
 	    if { [set infmt [lindex $argv 0]] == "" } { return 1 }
 	    foreach "in_ps in_ts tail" \
 		[CmdParseParamsTypes [lreplace $argv 0 0]] {}
@@ -237,7 +242,7 @@ proc BadCommandLine {} {
 	    # for the time being this is only supported for Garmin receivers
 	    if { $GPSREC != "Garmin" } { return 1 }
 	    if { [set COMMAND(path) [lindex $argv 0]] == "" || \
-		     [set n [llength $argv]] > 2 || \
+		     $nargs > 2 || \
 		     [set COMMAND(interv) \
 			  [CmdParseInteger [lindex $argv 1] 2]] < 0 } {
 		return 1
@@ -248,16 +253,23 @@ proc BadCommandLine {} {
 	    # for the time being this is only supported for Garmin receivers
 	    if { $GPSREC != "Garmin" } { return 1 }
 	    if { [set COMMAND(path) [lindex $argv 0]] == "" || \
-		     [set n [llength $argv]] > 2 || \
+		     $nargs > 2 || \
 		     [set COMMAND(timeout) \
 			  [CmdParseInteger [lindex $argv 1] 0]] < 0 } {
 		return 1
 	    }
 	}
+	getalmanac {
+	    # PATH
+	    # for the time being this is only supported for Garmin receivers
+	    if { $GPSREC != "Garmin" } { return 1 }
+	    if { $nargs != 1 } { return 1 }
+	    set COMMAND(path) [lindex $argv 0]
+	}
 	start {
 	    # travel [INTERVAL]
 	    if { [lindex $argv 0] != "travel" || $GPSREC != "Garmin" || \
-		     [set n [llength $argv]] > 2 || \
+		     $nargs > 2 || \
 		     [set COMMAND(interv) \
 			  [CmdParseInteger [lindex $argv 1] 2]] < 0 } {
 		return 1
@@ -268,7 +280,7 @@ proc BadCommandLine {} {
 	    # LATD LONGD DATUM PROJECTION [PARAMS]
 	    # making only a preliminary check on the correction of the
 	    #  arguments as projections.tcl was not yet loaded
-	    if { [llength $argv] < 4 } { return 1 }
+	    if { $nargs < 4 } { return 1 }
 	    foreach "latd longd" $argv { break }
 	    foreach p "latd longd" {
 		set x [set $p]
@@ -293,7 +305,7 @@ proc BadCommandLine {} {
 	    #  arguments as projections.tcl was not yet loaded
 	    set COMMAND(image) [lindex $argv 0]
 	    set COMMAND(transf) [set tr [lindex $argv 1]]
-	    if { [llength $argv] < 12 || \
+	    if { $nargs < 12 || \
 		    [lsearch -exact $MAPKNOWNTRANSFS $tr] == -1 } { return 1 }
 	    if { $tr == "NoRot" } {
 		# not using 3 points as when doing this by hand
@@ -328,12 +340,12 @@ proc BadCommandLine {} {
 	}
 	source {
 	    # PATH
-	    if { [llength $argv] != 1 } { return 1 }
+	    if { $nargs != 1 } { return 1 }
 	    set COMMAND(path) $argv
 	}
 	exec {
 	    # PATH
-	    if { [llength $argv] != 1 } { return 1 }
+	    if { $nargs != 1 } { return 1 }
 	    set COMMAND(path) $argv
 	}
 	read {
@@ -398,8 +410,9 @@ proc CmdParseProt {prot} {
 
 proc CmdParseTypes {lst} {
     # find element(s) at the beginning of $lst corresponding to item types:
-    #   either a single "all", or a subset of {WP, RT, TR, LN}
-    #  (note that $TYPES is not defined yet!)
+    #   either a single "all", or a subset of {WP, RT, TR, LN, LAP}
+    #   LAP is accepted only if $SUPPORTLAPS is set
+    #   (note that $TYPES is not defined yet!)
     # return pair with list of those elements and rest of list
 
     set pstslst [CmdParseParamsTypes $lst]
@@ -410,10 +423,12 @@ proc CmdParseTypes {lst} {
 proc CmdParseParamsTypes {lst} {
     # find element(s) at the beginning of $lst corresponding to
     #  parameters in the form NAME=VALUE, followed by item types:
-    #  either a single "all", or a subset of {WP, RT, TR, LN}
+    #  either a single "all", or a subset of {WP, RT, TR, LAP, LN}
+    #   LAP is accepted only if $SUPPORTLAPS is set
     #  (note that $TYPES is not defined yet!)
     # return triple with list of parameters (with alternating lhs and rhs),
     #  list of types and rest of list
+    global SUPPORTLAPS
 
     set ps ""
     while { [regexp {^(.+)=(.+)$} [lindex $lst 0] x lhs rhs] } {
@@ -424,7 +439,10 @@ proc CmdParseParamsTypes {lst} {
 	set ts all ; set lst [lreplace $lst 0 0]
     } else {
 	set ts ""
-	while { [lsearch -exact "WP RT TR LN" [lindex $lst 0]] != -1 } {
+	if { $SUPPORTLAPS } {
+	    set ats "WP RT TR LN LAP"
+	} else { set ats "WP RT TR LN" }
+	while { [lsearch -exact $ats [lindex $lst 0]] != -1 } {
 	    lappend ts [lindex $lst 0] ; set lst [lreplace $lst 0 0]
 	}
     }
@@ -442,14 +460,32 @@ proc CmdParseInteger {val default} {
     return $val
 }
 
-proc CmdRecTypes {lst} {
+proc CmdRecTypes {how lst} {
     # interpret list of item types to be get/put from/into receiver
+    #  $how in {get, put}
     #  $lst may be either "all", or non-empty subset of $TYPES-{LN,GR}
+    #  LAP is accepted only if $SUPPORTLAPS is set and $how=="get"
     #  (note that $TYPES is not defined yet!)
     # return "" on error, otherwise list of types as non-empty subset
     #  of $TYPES-{LN,GR}
+    global SUPPORTLAPS
 
-    if { $lst == "all" } { return "WP RT TR" }
+    if { $lst == "all" } {
+	if { $SUPPORTLAPS && $how == "get" } {
+	    return "WP RT TR LAP"
+	} else { return "WP RT TR" }
+    } else {
+	foreach t $lst {
+	    switch -- $t {
+		LN -  GR {
+		    return ""
+		}
+		LAP {
+		    if { ! $SUPPORTLAPS || $how == "put" } { return "" }
+		}
+	    }
+	}
+    }
     return $lst
 }
 
@@ -460,11 +496,12 @@ proc CmdFileFmtParamsTypes {how fmt pars ts} {
     #  $how in {in, out}
     #  $pars is list with each parameter name followed by corresponding value
     #  $ts is either "all", or subset of $TYPES-{GR}
+    #     LAP is only accepted if $SUPPORTLAPS is set
     # set COMMAND(filetypes), COMMAND(format), COMMAND($how,params)
     #  the latter in the same format as $pars but with all parameters in
     #  the order given by $FILEFORMAT($fmt,$how,params)
     # return 0 on error
-    global FILEFORMAT COMMAND
+    global FILEFORMAT COMMAND SUPPORTLAPS
 
     # compatibility with old versions
     if { $fmt == "gpsman" } {
@@ -539,6 +576,9 @@ proc CmdFileFmtParamsTypes {how fmt pars ts} {
 	    }
 	}
     }
+    if { [lsearch -exact $fts LAP] != -1 && ! $SUPPORTLAPS } {
+	return 0
+    }
     set COMMAND(format) $fmt
     set COMMAND($how,params) $pars
     set COMMAND(filetypes) $fts
