@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: elevation.tcl
-#  Last change:  7 September 2004
+#  Last change:  1 June 2006
 #
 # This file contains mostly code contributed by Alessandro Palmas
 #   (alpalmas@tin.it)
@@ -114,7 +114,7 @@ proc Hgraph {k what args} {
     #----
     global MESS TXT BITMAP
     # MF contribution
-    global NoImgLib ImgOutFormats DPOSX DPOSY MAPWIDTH MAPH2 PlotWNo
+    global NoImgLib ImgOutFormats DPOSX DPOSY MapWidth MAPH2 PlotWNo
 
     if { $args == "time" } {
 	set totdist 0
@@ -130,7 +130,7 @@ proc Hgraph {k what args} {
 
     # MX and MY are the width and heigth of the canvas
     # MF contrib: using map width and half map height
-    set MX $MAPWIDTH
+    set MX $MapWidth
     set MY $MAPH2
     if { $what == "climbrate" } {
 	# MF contrib
@@ -1195,8 +1195,9 @@ proc HG3D_canvas {alt} {
 		-command { HG3D_do_calc pow } -state disabled]
 	set HG3Dglob(shbutton) $s2k
         # MF contribution: using variable so that status is correctly displayed
+        set HG3Dglob(anim_en_b) $HG3Dglob(anim_en)
 	set s2r [checkbutton $f0a.sr2 -text $TXT(animate) \
-		-variable HG3Dglob(anim_en) \
+		-variable HG3Dglob(anim_en_b) \
 		-command "HG3D_animtog $w $s2" -selectcolor $COLOUR(check)]
 	#--
 	# MF contribution
