@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  22 October 2004
+#  Last change:  20 March 2006
 #
 # See also files_foreign.tcl
-#  and gpsman.tcl for properties of known file formats
+#  and metadata.tcl for properties of known file formats
 #
 # Includes contributions by
 #   - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
@@ -74,13 +74,17 @@ set FCOMMARGS {RT RS TR LN LAP GR GRWP GRRT GRTR GRLN GRLAP GRGR nb format
 array set FATTRPAIRS {
     WP {{symbol WPSymbol DEFAULTSYMBOL BadSymbol}
         {dispopt WPDispOpt DEFAULTDISPOPT BadDispOpt}
-        {alt WPAlt EMPTYSTR BadAltitude}}
+        {alt WPAlt EMPTYSTR BadAltitude}
+	{mapbak WPMBack EMPTYSTR Ignore}}
     RT {{width RTWidth DEFTRTWIDTH BadWidth}
-        {colour RTColour DEFTRTCOLOUR BadColour}}
+        {colour RTColour DEFTRTCOLOUR BadColour}
+	{mapbak RTMBack EMPTYSTR Ignore}}
     TR {{width TRWidth DEFTTRWIDTH BadWidth}
-        {colour TRColour DEFTTRCOLOUR BadColour}}
+        {colour TRColour DEFTTRCOLOUR BadColour}
+	{mapbak TRMBack EMPTYSTR Ignore}}
     LN {{width LNWidth DEFTLNWIDTH BadWidth}
-        {colour LNColour DEFTLNCOLOUR BadColour}}
+        {colour LNColour DEFTLNCOLOUR BadColour}
+	{mapbak LNMBack EMPTYSTR Ignore}}
     LAP {}
 }
 
@@ -673,7 +677,7 @@ proc SaveFileTo {f how what args} {
     # if $f=="" ask user to select output file
     # if $f!="stdout" file will be closed at the end
     # see proc SaveFile for the description of the arguments
-    global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS
+    global SFilePFrmt SFileDatum SFileHeader TXT TYPES SUPPORTLAPS File
 
     set stypes $TYPES
     if { $SUPPORTLAPS } { lappend stypes LAP }
@@ -691,15 +695,21 @@ proc SaveFileTo {f how what args} {
 	comp { }
 	mapinfo -  mapback { set slow 0 }
     }
+    set oldf $f
     if { $f != "" || [set f [GMOpenFile $TXT(saveto) $what w]] != ".." } {
 	if { $slow } {
 	    SlowOpWindow $TXT(save)
 	} else { SetCursor . watch }
 	set SFileHeader($f) 0
 	switch $how {
-	    comp -  mapinfo -
+	    comp -  mapinfo {
+		Save${what} $f $args
+	    }
 	    mapback {
 		Save${what} $f $args
+		if { $oldf == "" } {
+		    Define backgrnd "" $File(MapBkInfo) ""
+		}
 	    }
 	    default {
 		foreach p $lp {
@@ -726,7 +736,7 @@ proc SaveState {} {
     # slow operation dialog not used
     global USvState USvData USvMap MESS Number MapEmpty Map TYPES EdWindow \
 	    MapPFormat MapPFDatum MapPFNeedsDatum MapFont Travelling Travel \
-	    GMEd SUPPORTLAPS
+	    GMEd SUPPORTLAPS File
 
     set stypes $TYPES
     if { $SUPPORTLAPS } { lappend stypes LAP }
@@ -802,6 +812,12 @@ proc SaveState {} {
     }
     puts $f "\}"
     puts $f ""
+    puts $f "array set File \{"
+    foreach n [array names File] {
+	puts $f "   $n \{$File($n)\}"
+    }
+    puts $f "\}"
+    puts $f ""
     # must be the last instruction:
     puts $f "if \{ \[catch \{cd \"[pwd]\"\}\] \} \{"
     puts $f "  set saved \"[pwd]\""
@@ -815,7 +831,7 @@ proc RestoreState {} {
     # restore saved state and clear it if the user agrees
     global USvState MESS CREATIONDATE Proc DELSTATE MapPFormat Map MapFont \
 	    Travelling Travel MapEmpty ASKPROJPARAMS Datum MapPFDatum \
-	    MapPFNeedsDatum
+	    MapPFNeedsDatum File
 
     if { [file size $USvState] == 0 } { return }
     source $USvState
@@ -912,7 +928,7 @@ proc SaveCanvas {cv bounds fmt dest} {
     #  user GPSMan-data directory
     global PRINTCMD PAPERSIZE PAGEWIDTH PAGEHEIGHT GFMode GFRot \
 	    GFPaper GFLegend GFVisible GFScale GFPrintOption MESS TXT \
-	    MAPCOLOUR Map MpW MAPSCLENGTH USERDIR MapFont
+	    MAPCOLOUR Map MpW MAPSCLENGTH USERDIR MapFont FixedFont
 
     set leg "=$TXT(legend)"
     set cms [list $TXT(colour) $TXT(grey) $TXT(mono)]
@@ -946,7 +962,7 @@ proc SaveCanvas {cv bounds fmt dest} {
 	set font $MapFont
     } else {
 	set GFScale 0
-	set font fixed
+	set font $FixedFont
     }
     switch $dest {
 	file {
@@ -1279,14 +1295,16 @@ proc MakeComment {commt} {
 }
 
 proc FindPFormat {line} {
-    # parse position format
+    # parse position format; position format names cannot have blanks
     global NONGRIDFMTS GRIDS
 
-    foreach f $NONGRIDFMTS {
-	if { [string first $f $line] == 0 } { return $f }
-    }
-    foreach i $GRIDS {
-	if { [string first $i $line] == 0 } { return $i }
+    if { [regexp {^([^ ]+)} $line x pf] } {
+	foreach f $NONGRIDFMTS {
+	    if { $f == $pf } { return $f }
+	}
+	foreach i $GRIDS {
+	    if { $i == $pf } { return $i }
+	}
     }
     return BAD
 }
@@ -1600,8 +1618,8 @@ proc ReadPosn {fs i file} {
 	    } else { set gr 0 ; set zone "" }
 	    set eng [lindex $fs $i] ; incr i
 	    set nng [lindex $fs $i]
-	    if { ! [CheckNumber GMMessage $eng] || \
-		 ! [CheckNumber GMMessage $nng] } {
+	    if { ! [CheckFloat GMMessage $eng] || \
+		 ! [CheckFloat GMMessage $nng] } {
 	       return -1
 	    }
 	    if { [BadDatumFor $pformt $LFileDatum($file) GMMessage] != 0 } {
@@ -1695,7 +1713,7 @@ proc LoadWPs {file outRT importing how} {
 	set m [ReadFile $file]
 	if { $LFileEOF($file) } { return $wps }
 	if { [set m [CleanLine $m $importing]] == "" } { continue }
-	if { ! $importing && [string first ! $m]==0 } {
+	if { ! $importing && [string first ! $m] == 0 } {
 	    switch -glob [ProcCommand $m $file] {
 		WP -  RT -  TR -  LN -  LAP -
 		GR {
@@ -1774,8 +1792,9 @@ proc LoadWPs {file outRT importing how} {
 	} else {
 	    set date [Now] ; set i 2
 	}
-	set posn [ReadPosn $as $i $file] ; incr i $PosnLength
+	set posn [ReadPosn $as $i $file]
 	if { $posn == -1 } { return "" }
+	incr i $PosnLength
 	set hs ""
 	if { $n > $i } {
 	    if { $importing } {
