@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin.tcl
-#  Last change:  6 April 2006
+#  Last change:  4 June 2006
 #
 # Includes contributions by
 #  - David Gardner (djgardner@users.sourceforge.net) marked "DJG contribution"
@@ -32,6 +32,7 @@
  #  "Garmin GPS Interface Specification", April 24 2004, 001-00063-00 Rev. A
  #  "Garmin GPS Interface Specification", September 16 2004, 001-000063-00
  #   Rev. B
+ #  "Garmin GPS Interface Specification", May 19 2006, 001-000063-00 Rev. C
 
  # Garmin USB protocol is implemented assuming that the USB port is driven by
  #  the garmin_gps Linux kernel driver by Hermann Kneissel and part of the
@@ -70,7 +71,8 @@ proc OpenUSBFailed {} {
     # open USB port to use the Garmin USB protocol, and log file if needs be
     #  initialise USB driver
     # return 1 on failure
-    global SERIALPORT USBFILE GUSB USBPackets USBMissing USBBuff Eof MESS
+    global SERIALPORT USBFILE GUSB USBPackets USBMissing USBBuff Eof MESS \
+	USBHdrNeeded USBRecs
 
     if { [catch {set USBFILE [open $SERIALPORT r+]}] } {
 	GMMessage [format $MESS(badserial) $SERIALPORT]
@@ -92,13 +94,15 @@ proc OpenUSBFailed {} {
 	[DataToStr "long long long" \
 	     [list $GUSB(LAYERID,TRANSPORT) \
 		  $GUSB(PID,TRANSPORT,START,SESSION,REQ) 0]]
+    flush $USBFILE
     # read and discard anything there is to be read
     # should have waited for a session started packet at the transport level
-    after 2
+    after 10
     read $USBFILE
     # initialise input and open log file
     set Eof 0
-    set USBPackets "" ; set USBMissing 0 ; set USBBuff ""
+    set USBPackets "" ; set USBMissing 0 ; set USBHdrNeeded 12 ; set USBBuff ""
+    set USBRecs 0
     fileevent $USBFILE readable ReadUSB
     OpenSerialLog
     return 0
@@ -145,27 +149,45 @@ proc ReadUSB {} {
     # read bytes and form a complete Garmin USB packet
     # complete packets are kept in the list $USBPackets and
     #  proc UseUSBInput called to process them when needed
-    global USBFILE Eof USBPackets NoInProc GUSB USBMissing USBBuff USBPId RPID
+    global USBFILE Eof USBPackets NoInProc GUSB USBMissing USBHdrNeeded \
+	USBBuff USBPId USBRecs RPID
 
     if { $Eof } { return }
     if { $USBMissing == 0 } {
-	# read USB packet header
-	set buff [read $USBFILE 12]
-	if { [set n [string length $buff]] != 12 } {
-	    Log "RU> bad packet header, only $n bytes not 12; discarded"
-	    return
+	while 1 {
+	    # read (rest of) USB packet header
+	    if { [catch {set buff [read $USBFILE $USBHdrNeeded]}] || \
+		 [set n [string length $buff]] == 0 } {
+		# no more data to be read
+		return
+	    }
+	    if { $n != $USBHdrNeeded } {
+		Log "RU> only $n bytes not $USBHdrNeeded for header"
+		set USBHdrNeeded [expr $USBHdrNeeded-$n]
+		return
+	    }
+	    set USBHdrNeeded 12
+	    foreach "layerid USBPId USBMissing" \
+		[UnPackData [split $buff ""] "long long long"] { break }
+	    Log "RU> layerid=$layerid, pid=$USBPId, length=$n"
+	    if { $layerid == $GUSB(LAYERID,TRANSPORT) } {
+		Log "RU> transport layer packet discarded"
+		if { $USBMissing != 0 } {
+		    read $USBFILE $USBMissing
+		    set USBMissing 0
+		}
+		continue
+	    }
+	    if { $layerid != $GUSB(LAYERID,APPL) || \
+		     [catch {set USBPId $RPID($USBPId)}] } {
+		Log "RU> bad layer id or pid; discarding all data to be read"
+		read $USBFILE
+		set USBMissing 0
+		return
+	    }
+	    set USBBuff ""
+	    break
 	}
-	foreach "layerid USBPId USBMissing" \
-	    [UnPackData [split $buff ""] "long long long"] { break }
-	Log "RU> layerid=$layerid, pid=$USBPId, length=$n"
-	if { $layerid != $GUSB(LAYERID,APPL) || \
-		 [catch {set USBPId $RPID($USBPId)}] } {
-	    Log "RU> bad layer id or pid; discarding all data to be read"
-	    read $USBFILE
-	    set USBMissing 0
-	    return
-	}
-	set USBBuff ""
     }
     # read USB data
     set pdata [read $USBFILE $USBMissing]
@@ -178,7 +200,14 @@ proc ReadUSB {} {
     Log "RU> complete packet got: length $nn"
     lappend USBPackets [list $USBPId $USBBuff]
     set USBMissing 0
-    if { $NoInProc } { after 0 UseUSBInput }
+    if { $USBRecs } {
+	if { $USBPId == "XfrCmpl" } {
+	    set USBRecs 0
+	    if { $NoInProc } { after 0 UseUSBInput }
+	}
+    } elseif { $USBPId == "Records" } {
+	set USBRecs 1
+    } elseif { $NoInProc } { after 0 UseUSBInput }
 
     if { [set Eof [eof $USBFILE]] } {
 	Log "RU> at eof"
@@ -220,7 +249,9 @@ proc ProcLineChar {char} {
 
 proc UseUSBInput {} {
     # use packets read from USB channel in list $USBPackets
-    global USBPackets NoInProc
+    # loop until either a Records packet was detected by proc ReadUSB
+    #  or no more packets were queued
+    global USBPackets NoInProc USBRecs
 
     set NoInProc 0
     while 1 {
@@ -230,9 +261,9 @@ proc UseUSBInput {} {
 	    set pdata [split $pdata ""]
 	    LogBytes "UUI> got packet pid=$pid; contents:" $pdata
 	    ProcInPacket $pid $pdata
+	    update
 	}
-	update
-	if { $USBPackets == "" } { break }
+	if { $USBRecs || $USBPackets == "" } { break }
     }
     set NoInProc 1
     return
@@ -261,7 +292,8 @@ proc SendUSBPacket {pid types vals} {
     LogBytes "SUP> sending packet $pid with:" [split $pak ""]
     puts -nonewline $USBFILE $pak
     flush $USBFILE
-    SentPacket $pid
+    # to avoid a too deep recursion do not use a direct call
+    after 0 "SentPacket $pid"
     return
 }
 
@@ -737,7 +769,7 @@ proc ProcInPacket {pid data} {
 	    regsub {EXF$} $PkInState "" prot
 	    EndOfTransfer $pid $data TR $prot $PkInData
 	}
-	D300 -  D301 -  D302 {
+	D300 -  D301 -  D302 -  D303 -  D304 {
 	    # TR data; product specific
 	    if { $pid == "TRHeader" } {
 		set PkInState $CurrPSPID(TRHeader)
@@ -884,16 +916,18 @@ proc SendData {type args} {
     #  USB mode SentPacket will be called after the packet is sent
     #   $type in {product, abort, turnOff, get, put, start, stop}
     #   $args void unless
-    #       $type==get: in {WP RT TR PosnData DtTmData}; not yet
-    #                    in {AL Prx}
+    #       $type==get: in {WP RT TR AL PosnData DtTmData}; not yet
+    #                    in {Prx}
     #       $type==put and 1st arg in {WP RT TR PosnData DtTmData}; not yet
     #                    in {AL Prx}
     #                   2nd arg is list of indices
     #       $type in {start, stop}: in {PVT}
+    # set global GPSOpResult to 1 (error) if put operation fails
     global PDTYPE PRTHNID PkInState SOutBusy CurrPSPID CMD Command CommArgs \
-	    PkOutState PkOutData PkOutCount PkOutStart PkOutWhat PkTRSegs \
-	    PkOutSaved PkOutInfo RTIdNumber RTWPoints RTStages TRTPoints \
-	    TRSegStarts PrdDATA MESS PTRHNID ProcSendPacket
+	PkOutState PkOutData PkOutCount PkOutStart PkOutWhat PkTRSegs \
+	PkOutSaved PkOutInfo RTIdNumber RTWPoints RTStages TRTPoints \
+	TRSegStarts PrdDATA MESS PTRHNID ProcSendPacket PROTNOOUTPUT \
+	GPSOpResult
     # DJG contribution
     global RTNextNumber AutoNumRts RTSendNumber
     #--
@@ -921,16 +955,30 @@ proc SendData {type args} {
 	    $ProcSendPacket CmdData int $CMD(Stop$args)
 	}
 	get {
-	    # $args in {WP RT TR PosnData DtTmData}
-	    #  not implemented: {AL Prx}
+	    # $args in {WP RT TR AL PosnData DtTmData}
+	    #  not implemented: {Prx}
 	    $ProcSendPacket CmdData int $CMD(Xfr$args)
 	}
 	put {
 	    set putwhat [lindex $args 0]
 	    set ixs [lindex $args 1]
-	    if { $putwhat == "Prx" || $putwhat == "AL" } {
-		Log "put $putwhat not implemented"
-		return
+	    foreach z $PROTNOOUTPUT {
+		if { [lindex $z 0] == $putwhat } {
+		    if { [set z [lindex $z 1]] == "" } {
+			Log "SD> put $putwhat not implemented"
+			set GPSOpResult 1
+			return
+		    }
+		    foreach zz $z {
+			foreach "zt zid" $zz {}
+			if { ! [catch {set zc $CurrPSPID($zt)}] && \
+				 $zc == $zid } {
+			    Log "SD> put: $zt protocol $zid not implemented"
+			    set GPSOpResult 1
+			    return
+			}
+		    }
+		}
 	    }
 	    set PkOutWhat $putwhat
 	    set p $CurrPSPID($putwhat)
@@ -1279,7 +1327,7 @@ proc PrepData {} {
 	    set PkOutData [lreplace $PkOutData 0 0]
 	    return [list $PDTYPE($PkOutState) [PrepRSData $PkOutState $st]]
 	}
-	D300 -  D301 -  D302 {
+	D300 -  D301 -  D302 -  D303 -  D304 {
 	    if { $PkOutSaved != "" } {
 		# $PkOutSaved is list of TPs
 		set p [lindex $PkOutSaved 0]
@@ -1450,7 +1498,7 @@ proc PrepTRHeader {pid name colour hidden} {
 
     switch $pid {
 	D310 -  D312 {
-	    set ps "0 2" ; set vs [list [ToGarminColour $pid $colour] $name]
+	    set ps "1 2" ; set vs [list [ToGarminColour $pid $colour] $name]
 	}
 	D311 {
 	    set ps 0 ; set vs $name
@@ -1461,20 +1509,32 @@ proc PrepTRHeader {pid name colour hidden} {
 
 proc PrepTRData {pid posn date new alt depth} {
 
+    if { $alt != "" } {
+	set altundef $alt
+    } else { set altundef 1.0e25 }
+    if { $depth != "" } {
+	set depthundef $depth
+    } else { set depthundef 1.0e25 }
     switch $pid {
 	D300 {
 	    return [list $posn $date $new]
 	}
 	D301 {
-	    if { $alt == "" } { set alt 1.0e25 }
-	    if { $depth == "" } { set depth 1.0e25 }
-	    return [list $posn $date $alt $depth $new]
+	    return [list $posn $date $altundef $depthundef $new]
 	}
 	D302 {
-	    if { $alt == "" } { set alt 1.0e25 }
-	    if { $depth == "" } { set depth 1.0e25 }
 	    # temperature is always sent as undefined
-	    return [list $posn $date $alt $depth 1.0e25 $new]
+	    return [list $posn $date $altundef $depthundef 1.0e25 $new]
+	}
+	D303 {
+	    # heart rate is always sent as undefined
+	    # no information on new segments
+	    return [list $posn $date $altundef 0]
+	}
+	D304 {
+	    # heart rate, cadence always sent as undefined and sensor as 0
+	    # no information on new segments
+	    return [list $posn $date $altundef 1.025 0 0xff 0]
 	}
     }
 }
@@ -1805,6 +1865,7 @@ proc ToGarminColour {pid colour} {
     set cs "" ; set c 0
     foreach n $GARMINCOLOURS($pid) {
 	foreach "x y z" [ColourToDec $n] {}
+	if { $x == -1 } { continue }
 	if { $x == $cx && $y == $cy && $z == $cz } { return $c }
 	lappend cs $c $x $y $z
 	incr c
@@ -1816,7 +1877,8 @@ proc FromGarminColour {pid code} {
     # convert from Garmin code to GPSMan colour (in hexadecimal)
     global GARMINCOLOURS RGBNamed
 
-    if { [set name [lindex $GARMINCOLOURS($pid) $code]] == "" } {
+    if { [set name [lindex $GARMINCOLOURS($pid) $code]] == "" || \
+	     $name == "default" } {
 	set defvar $GARMINCOLOURS($pid,dvar)
 	global $defvar
 	return [set $defvar]
@@ -1831,7 +1893,7 @@ proc EndInProt {pid data} {
     #  $pid in {A000 A001 A010 A100 A200-201 A300-302 A500 A600 A650
     #           A700 A906}
     #    (cf. ProcInPacket) but {A010 A500 A600 A650 A700} not supported here
-    # global $Request==get$wh  where $wh in {WP RT TR LAP PosnData
+    # global $Request==get$wh  where $wh in {WP RT TR LAP AL PosnData
     #                          DtTmData} (cf. SendData)
     #                         GPSOpResult is set to 0 on success or 1 on error
     #                ==check=$args  where 1st arg should be executed as
@@ -1941,14 +2003,18 @@ proc ConvWPData {data pid} {
     foreach d $data {
 	set vs $cnsts
 	lappend vs [set hvs [HiddenGet $pid $d]]
+	set ok 1
 	foreach f $fs p $ps {
 	    set v [lindex $d $p]
 	    switch $f {
 		Posn {
 		    foreach "latd longd" $v { break }
-		    if { $pid == "D110" && abs($latd) > 0x40000000 } {
+		    if { ( $pid == "D110" && abs($latd) > 0x40000000 ) || \
+			     abs($latd) > 90 || abs($longd) > 180 } {
 			# discard
-			continue
+			Log "CWPD> WP bad position, $pid: $latd $longd"
+			set ok 0
+			break
 		    }
 		    foreach "v pfmt datum" \
 			[FormatPosition $latd $longd "WGS 84" \
@@ -1988,7 +2054,7 @@ proc ConvWPData {data pid} {
 	    }
 	    lappend vs $v
 	}
-	lappend r [FormData WP $all $vs]
+	if { $ok } { lappend r [FormData WP $all $vs] }
     }
     return $r
 }
@@ -2068,7 +2134,7 @@ proc InDataTR {data} {
     # add TRs data from receiver to database
     #  $data is a list of pairs with kind (in {header, data}) and list of
     # values
-    global CurrPSPID GetDispl
+    global CurrPSPID GetDispl SegPrefix
 
     # $trs is a list of triples with TR header info, a list of TP info, and
     #  a list of segment starters, where the TR header info is a pair with
@@ -2084,7 +2150,9 @@ proc InDataTR {data} {
 		    Log "IDTR> got a non-data pair: [lindex $p 0]"
 		    return
 		}
-		set tpp [ConvTPData $vals $pidd]
+		if { [set tpp [ConvTPData $vals $pidd]] == "" } {
+		    continue
+		}
 		if { [lindex $tpp 0] == 1 && $tps != "" } {
 		    lappend trs [list "" $tps ""]
 		    set tps ""
@@ -2099,10 +2167,14 @@ proc InDataTR {data} {
 	    # segments are supported
 	    set pidh $CurrPSPID(TRHeader)
 	    set phdr "" ; set segsts "" ; set tpn 0
+	    # for dealing with segments marked with invalid packets
+	    set SegPrefix 0
 	    foreach p $data {
 		set vals [lindex $p 1]
 		if { [lindex $p 0] != "header" } {
-		    set tpp [ConvTPData $vals $pidd]
+		    if { [set tpp [ConvTPData $vals $pidd]] == "" } {
+			continue
+		    }
 		    lappend tps [lindex $tpp 1]
 		    if { [lindex $tpp 0] && $tpn != 0 } {
 			lappend segsts $tpn
@@ -2165,17 +2237,29 @@ proc ConvTRHeaderData {data pid} {
 
 proc ConvTPData {data pid} {
     # convert TP data
-    # return pair with flag indicating a new TR or segment, and list obtained
-    #  by FormData
+    # return empty list if invalid packet, otherwise pair with flag indicating
+    #  a new TR or segment, and list obtained by FormData
+    global SegPrefix
 
     set fs "" ; set vs ""
-    # similar fields: position, date
-    set p [lindex $data 0] ; set d [lindex $data 1]
+    # common fields: position, date
+    set badpos 0
+    foreach "latd longd" [lindex $data 0] {}
+    if { abs($latd) > 90 || abs($longd) > 180 } { incr badpos }
+    set d [lindex $data 1]
     switch $pid {
 	D300 {
+	    if { $badpos } {
+		Log "CTPD> TP bad position: $latd $longd"
+		return ""
+	    }
 	    set new [lindex $data 2]
 	}
 	D301 -  D302 {
+	    if { $badpos } {
+		Log "CTPD> TP bad position: $latd $longd"
+		return ""
+	    }
 	    if { [set alt [lindex $data 2]] < 1e10 } {
 		lappend fs alt ; lappend vs $alt
 	    }
@@ -2185,11 +2269,45 @@ proc ConvTPData {data pid} {
 	    if { $pid == "D302" } {
 		# discard temperature
 		set new [lindex $data 5]
-	    } else { set new [lindex $data 4] }
+	    } else {
+		# D301
+		set new [lindex $data 4]
+	    }
+	}
+	D303 -  D304 {
+	    # segments are prefixed with 2 packets whose fields are all invalid
+	    set prefix $badpos
+	    if { [set alt [lindex $data 2]] < 1e10 } {
+		lappend fs alt ; lappend vs $alt
+		set prefix 0
+	    }
+	    if { $pid == "D303" } {
+		if { [set heartrate [lindex $data 3]] != 0 } { set prefix 0 }
+	    } else {
+		# D304
+		foreach "dist heartrate cadence sensor" [lreplace $data 0 2] {}
+		if { $heartrate != 0 || abs($dist-1.0e25) > 1 || \
+			 $sensor != 0xff } { set prefix 0 }
+	    }
+	    if { $prefix } {
+		Log "CTPD> segment prefix discarded"
+		incr SegPrefix
+		return ""
+	    }
+	    if { $badpos } {
+		Log "CTPD> TP bad position: $latd $longd"
+		set SegPrefix 0
+		return ""
+	    }
+	    # discard all information except position, date and altitude
+	    if { $SegPrefix > 1 } {
+		set new 1
+	    } else { set new 0 }
+	    set SegPrefix 0
 	}
     }
-    if { [catch {set np [FormatLatLong [lindex $p 0] [lindex $p 1] DMS]}] } {
-	Log "ConvTPData> bad position: p=$p\ndata=$data"
+    if { [catch {set np [FormatLatLong $latd $longd DMS]}] } {
+	Log "CTPD> bad position: $latd $longd\ndata=$data"
 	GMMessage "Error getting TPs; please report to mig@ncc.up.pt"
 	return [list 1 {}]
     }
@@ -2387,6 +2505,8 @@ proc InDataPVT {data pid} {
 	    # some old receivers may use a fix value that is 1 more than this
 	    #  (Garmin specs 1 rev A); that is not dealt with here!!!
 	    if { $fix < 2 } { return "" }
+	    foreach "latd longd" $posn {}
+	    if { abs($latd) > 90 || abs($longd) > 180 } { return "" }
 	    if { $fix%2 == 0 } {
 		set alt "_" ; set valt "_"
 	    } else { set alt [expr $alt+$mslh] }
@@ -2891,7 +3011,7 @@ proc InitGivenProtocols {data} {
     # return 0 on error
     global CurrPSPID PROTTAG PROTCAT PROTREQ PSPROTOCOLS PSPDEF PID RPID \
 	    PSCMDDEF CMD MyProdId MyProdDescr MyProdVersion NotLogging \
-	    USERDIR PRTCLDEF MESS VERSION
+	    USERDIR PRTCLDEF MESS VERSION PDTYPE
 
     set npf [file join $USERDIR $MyProdId.prt]
     if { $NotLogging && [catch {set PRTCLDEF($MyProdId)}] && \
@@ -2955,6 +3075,7 @@ proc InitGivenProtocols {data} {
 		    }
 		    if { $outpfile } { puts $pfile "Application: $p$info" }
 		    Log "IGP> Application: $p$info"
+		    set notav 0
 		    foreach dp $PROTREQ($p) {
 			set st [lindex $data 0]
 			set t [lindex $st 0]
@@ -2967,7 +3088,8 @@ proc InitGivenProtocols {data} {
 			    Log "IGP> unknown tag: $t\n>>$st<<"
 			    incr error
 			    continue
-			} elseif { $tag != "Data" } {
+			}
+			if { $tag != "Data" } {
 			    if { $outpfile } {
 				puts $pfile \
 				  "Error: missing data protocol for $p: $odata"
@@ -2976,9 +3098,31 @@ proc InitGivenProtocols {data} {
 			    incr error
 			    continue
 			}
-			set CurrPSPID($dp) ${t}$n
-			if { $outpfile } { puts $pfile "Data: ${t}$n" }
-			Log "IGP> Data: ${t}$n"
+			set dprot "$t$n"
+			if { [catch {set dtdp $PDTYPE($dprot)}] } {
+			    if { $outpfile } {
+				puts $pfile \
+				  "Error: unknown data protocol $dprot: $odata"
+			    }
+			    Log "IGP> unknown data protocol $dprot: $odata"
+			    incr notav
+			} elseif { $dtdp == "nospec" } {
+			    if { $outpfile } {
+				puts $pfile \
+				  "Data: $dprot (nospec)"
+			    }
+			    Log "IGP> Data: $dprot (nospec)"
+			    incr notav
+			} else {
+			    set CurrPSPID($dp) $dprot
+			    if { $outpfile } { puts $pfile "Data: $dprot" }
+			    Log "IGP> Data: $dprot"
+			}
+		    }
+		    if { $notav } {
+			set CurrPSPID($ct) N/A
+			if { $outpfile } { puts $pfile "... $p N/A" }
+			Log "IGP> ... $p N/A"
 		    }
 		}
 	    }
@@ -3033,7 +3177,7 @@ proc InitProtocols {prodid} {
     #  from the default table
     #  $prodid is the product identifier
     global PRTCLDEF PSPROTOCOLS PSPID PSDIFF PSPDEF PSCMDDEF CurrPSPID \
-	    CMD PID RPID PROTREQ
+	    CMD PID RPID PROTREQ PDTYPE
 
     switch -glob $PRTCLDEF($prodid) {
 	array {
@@ -3041,7 +3185,14 @@ proc InitProtocols {prodid} {
 		if { ! [catch {set pid $PSPID($prodid,$p)}] } {
 		    set CurrPSPID($p) $pid
 		    foreach dp $PROTREQ($pid) {
-			set CurrPSPID($dp) $PSPID($prodid,$dp)
+			set dprot $PSPID($prodid,$dp)
+			if { [catch {set dtdp $PDTYPE($dprot)}] || \
+				 $dtdp == "nospec" } {
+			    Log "IP> unknown/nospec protocol $dprot for $p"
+			    set CurrPSPID($p) N/A
+			    break
+			}
+			set CurrPSPID($dp) $dprot
 		    }
 		}
 	    }
@@ -3059,7 +3210,7 @@ proc InitProtocols {prodid} {
 	}
 	diff {
 	    InitProtocols [lindex $PSDIFF($prodid) 0]
-	    foreach d [lrange $PSDIFF($prodid) 1 end] {
+	    foreach d [lreplace $PSDIFF($prodid) 0 0] {
 		set CurrPSPID([lindex $d 0]) [lindex $d 1]
 	    }
 	}
