@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: gendials.tcl
-#  Last change:  16 September 2004
+#  Last change:  6 April 2006
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
@@ -321,7 +321,7 @@ proc DisplayInfo {mess} {
     # display information on a dialog
     # the dialog is created if it not exists, otherwise the message
     #  will be added to it
-    global CMDLINE COLOUR EPOSX EPOSY TXT
+    global CMDLINE COLOUR EPOSX EPOSY TXT FixedFont
 
     if { $CMDLINE } { return }
 
@@ -337,8 +337,8 @@ proc DisplayInfo {mess} {
 	label .gminfo.fr.title -text $TXT(info) -relief sunken
 
 	frame $frt -relief flat -borderwidth 0
-	text $frt.txt -width 70 -font fixed -wrap word -exportselection 1 \
-	    -yscrollcommand "$frt.tscrl set"
+	text $frt.txt -width 70 -font $FixedFont -wrap word \
+	    -exportselection 1 -yscrollcommand "$frt.tscrl set"
 	bind $frt.txt <space> "$frt.txt yview scroll 1 pages ; break"
 	bind $frt.txt <Key-Delete> "$frt.txt yview scroll -1 pages ; break"
 	bind $frt.txt <Any-Key> break
@@ -347,10 +347,13 @@ proc DisplayInfo {mess} {
 
 	set frb .gminfo.fr.frb
 	frame $frb -relief flat -borderwidth 0
+	button $frb.save -text $TXT(save) \
+	    -command "SaveDisplayInfo $frt.txt"
 	button $frb.ok -text $TXT(ok) -command { destroy .gminfo }
 
 	grid config $frt.txt -column 0 -row 1 -sticky nesw
 	grid config $frt.tscrl -column 1 -row 1 -sticky nesw
+	grid config $frb.save -column 0 -row 0
 	grid config $frb.ok -column 1 -row 0
 	pack .gminfo.fr.title $frt $frb -side top -pady 5
 	pack .gminfo.fr
@@ -361,6 +364,17 @@ proc DisplayInfo {mess} {
     return
 }
 
+proc SaveDisplayInfo {wtxt} {
+    # save text in $wtxt text widget to file
+    global TXT
+
+    if { [set txt [$wtxt get 1.0 end]] == "" || \
+	     [set f [GMOpenFile $TXT(saveto) Plot w]] == ".." } { return }
+    puts $f $txt
+    close $f
+    return
+}
+
 ### dialog window for controlling slow operations
 
 proc SlowOpWindow {mess} {
@@ -372,7 +386,8 @@ proc SlowOpWindow {mess} {
     #  and returns 0  otherwise
     # any call within the loop to GMMessage will be diverted to this dialog
     # after the main loop there should be a call to proc SlowOpFinish
-    global SlowOp COLOUR MAPCOLOUR EPOSX EPOSY TXT CMDLINE USESLOWOPWINDOW
+    global SlowOp COLOUR MAPCOLOUR EPOSX EPOSY TXT CMDLINE USESLOWOPWINDOW \
+	FixedFont
 
     if { $CMDLINE || ! $USESLOWOPWINDOW } { return }
 
@@ -399,7 +414,7 @@ proc SlowOpWindow {mess} {
 
     set frt .slowop.fr.frt
     frame $frt -relief flat -borderwidth 0
-    text $frt.txt -width 50 -font fixed -wrap word \
+    text $frt.txt -width 50 -font $FixedFont -wrap word \
 	    -yscrollcommand "$frt.tscrl set"
     bind $frt.txt <space> "$frt.txt yview scroll 1 pages ; break"
     bind $frt.txt <Key-Delete> "$frt.txt yview scroll -1 pages ; break"
@@ -495,12 +510,15 @@ proc SlowOpAborted {} {
 proc GMOpenFile {act wh mode} {
     # create modal dialog for selecting and opening a file
     #  $act is string describing the action to do on the file
-    #  $wh in $FileTypes (see proc GMStart, main.tcl)
+    #  $wh in $filetypes (see proc GMStart, main.tcl)
     #  $mode in {r, w}
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
-    global GMResult COLOUR DPOSX DPOSY LISTHEIGHT File FileTypes TXT MESS \
-	    UNIX
+    global GMResult COLOUR DPOSX DPOSY LISTHEIGHT File TXT MESS UNIX
+
+    if { [set f $File($wh)] == "" || [catch {cd [file dirname $f]}] } {
+	set currfile ""
+    } else { set currfile [file tail $f] }
 
     toplevel .fdlg
     wm protocol .fdlg WM_DELETE_WINDOW { set GMResult cnc }
@@ -538,7 +556,7 @@ proc GMOpenFile {act wh mode} {
     FillDir .fdlg.fr.frbx.box
 
     entry .fdlg.fr.fn -width 30
-    .fdlg.fr.fn insert 0 $File($wh)
+    .fdlg.fr.fn insert 0 $currfile
     TextBindings .fdlg.fr.fn
     
     frame .fdlg.fr.bs
@@ -574,7 +592,7 @@ proc GMOpenFile {act wh mode} {
 		set fn [.fdlg.fr.fn get]
 		set f [GMCheckFile open $fn $mode]
 		if { $f != ".." } {
-		    set File($wh) $fn
+		    set File($wh) [file join [pwd] $fn]
 		    set res $f
 		    break
 		}
@@ -584,13 +602,12 @@ proc GMOpenFile {act wh mode} {
 		ShowTEdit .fdlg.fr.wdir [pwd] 0
 		.fdlg.fr.frbx.box delete 0 end ; FillDir .fdlg.fr.frbx.box
 		.fdlg.fr.fn delete 0 end
-		foreach i $FileTypes { set File($i) "" }
 	    }
 	    default {
 		set fn [.fdlg.fr.frbx.box get $GMResult]
 		set f [GMCheckFile open $fn $mode]
 		if { $f != ".." } {
-		    set File($wh) $fn
+		    set File($wh) [file join [pwd] $fn]
 		    set res $f
 		    break
 		}
@@ -605,7 +622,6 @@ proc GMOpenFile {act wh mode} {
 proc GMOpenFileParms {act wh mode vars vals} {
     # create modal dialog for selecting and opening a file and parameters
     # see arguments of proc GMGetFileName
-    global File
 
     set fname [GMGetFileName $act $wh $mode $vars $vals]
     if { $fname == ".." } { return ".." }
@@ -615,14 +631,17 @@ proc GMOpenFileParms {act wh mode vars vals} {
 proc GMGetFileName {act wh mode vars vals} {
     # create modal dialog for selecting a file name and parameters
     #  $act is string describing the action to do on the file
-    #  $wh in $FileTypes (see proc GMStart, main.tcl)
+    #  $wh in $filetypes (see proc GMStart, main.tcl)
     #  $mode in {r, w}
     #  $vars is list of (global) vars to set
     #  $vals is associated list of value descriptions (see proc GMSetupParams)
     #  buttons: OK, Cancel
     #  binding: return and double-left for commit, left-click for select
-    global GMResult COLOUR DPOSX DPOSY LISTHEIGHT File FileTypes TXT MESS \
-	    UNIX
+    global GMResult COLOUR DPOSX DPOSY LISTHEIGHT File TXT MESS UNIX
+
+    if { [set f $File($wh)] == "" || [catch {cd [file dirname $f]}] } {
+	set currfile ""
+    } else { set currfile [file tail $f] }
 
     toplevel .fdlg
     wm protocol .fdlg WM_DELETE_WINDOW { set GMResult cnc }
@@ -664,7 +683,7 @@ proc GMGetFileName {act wh mode vars vals} {
     Mscroll .fdlg.fr.frbx.box
 
     entry .fdlg.fr.fn -width 30
-    .fdlg.fr.fn insert 0 $File($wh)
+    .fdlg.fr.fn insert 0 $currfile
     TextBindings .fdlg.fr.fn
 
     frame .fdlg.fr.fopt
@@ -704,7 +723,7 @@ proc GMGetFileName {act wh mode vars vals} {
 		set fn [.fdlg.fr.fn get]
 		set f [GMCheckFile check $fn $mode]
 		if { $f != ".." } {
-		    set File($wh) $fn
+		    set File($wh) [file join [pwd] $fn]
 		    GMUseEntries .fdlg.fr.fopt $es
 		    set res $fn
 		    break
@@ -715,13 +734,12 @@ proc GMGetFileName {act wh mode vars vals} {
 		ShowTEdit .fdlg.fr.wdir [pwd] 0
 		.fdlg.fr.frbx.box delete 0 end ; FillDir .fdlg.fr.frbx.box
 		.fdlg.fr.fn delete 0 end
-		foreach i $FileTypes { set File($i) "" }
-	        }
+	    }
 	    default {
 		set fn [.fdlg.fr.frbx.box get $GMResult]
 		set f [GMCheckFile check $fn $mode]
 		if { $f != ".." } {
-		    set File($wh) $fn
+		    set File($wh) [file join [pwd] $fn]
 		    set res $fn
 		    break
 		}
@@ -738,7 +756,7 @@ proc GMCheckFile {how f mode} {
     #  or return file name; otherwise return ".."
     #  $how in {open check}
     #  $mode in {r, w}
-    global PERMS File FileTypes TXT MESS
+    global PERMS TXT MESS
 
     if { $f == "" } { bell ; return ".." }
     if { [file isdirectory $f] } {
@@ -748,7 +766,6 @@ proc GMCheckFile {how f mode} {
 	    .fdlg.fr.frbx.box delete 0 end
 	    FillDir .fdlg.fr.frbx.box
 	    .fdlg.fr.fn delete 0 end
-	    foreach i $FileTypes { set File($i) "" }
 	} else {
 	    bell
 	}
@@ -787,14 +804,12 @@ proc GMCheckFile {how f mode} {
 
 proc ChangeVolume {w vol} {
     # file volume has changed $vol in file-selection dialog $w
-    global FileTypes
 
     if { ! [file isdirectory $vol] } { bell ; return }
     cd $vol
     ShowTEdit .fdlg.fr.wdir [pwd] 0
     .fdlg.fr.frbx.box delete 0 end ; FillDir .fdlg.fr.frbx.box
     .fdlg.fr.fn delete 0 end
-    foreach i $FileTypes { set File($i) "" }
     return
 }
 
