@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: geod.tcl
-#  Last change:  19 May 2004
+#  Last change:  17 April 2006
 #
 
 ## Most of the geodetic information herein taken or adopted from
@@ -98,7 +98,7 @@ proc DatumWithRefId {n} {
 ###### known datums
      # when changing this list make sure you update the definitions below
 
-proc FillDatumMenu {menu commd args} {
+proc FillDatumMenu {menu commdargs args} {
     # fill menu with known datum names
     # see proc FillMenu (utils.tcl) for the details on the arguments
     #  $args not used
@@ -109,6 +109,7 @@ proc FillDatumMenu {menu commd args} {
 	--- \
 	@ [list Europe \
                 Austrian "Austrian (MGI)" "CH-1903" "Datum 73" \
+	        "Deutsches Hauptdreiecksnetz" \
 		"Estonia Coord System 1937" "ED73" \
 		@ [list "European 1950" \
 		   "European 1950" "European 1950; Belgium" \
@@ -260,7 +261,7 @@ proc FillDatumMenu {menu commd args} {
 	set ud [linsert $UDatums 0 "$TXT(userdefs)..."]
 	set descr [linsert $descr 0 @ $ud ---]
     }
-    FillMenu $menu "$commd" $descr
+    FillMenu $menu $commdargs $descr
     return
 }
 
@@ -1296,7 +1297,7 @@ array set GDATUM {
     gm155 "" -1 -1 -1 0}
 
 "Datum 73" { "International 1924"
-    223.237 110.193 -37
+    223.237 110.193 -36.649
     gm156 "Portugal" -1 -1 -1 0}
 
 "Dionisos" { "GRS 80"
@@ -1330,12 +1331,16 @@ array set GDATUM {
 "Norsk" { "Bessel 1841 (Norway)"
     278 93 474
     gm164 ""}
+
+"Deutsches Hauptdreiecksnetz" { "Bessel 1841"
+    598.1 73.7 418.2
+    gm164 ""}
 }
 
 ###### known ellipsoids
      # when changing this list make sure you update the definitions below
 
-proc FillEllipsoidMenu {menu commd} {
+proc FillEllipsoidMenu {menu commdargs} {
     # fill menu with known ellipsoid names
     # see proc FillMenu (utils.tcl) for the details on the arguments
     global TXT UEllipsoids
@@ -1374,7 +1379,7 @@ proc FillEllipsoidMenu {menu commd} {
 	set ud [linsert $UEllipsoids 0 "$TXT(userdefs)..."]
 	set descr [linsert $descr 0 @ $ud ---]
     }
-    FillMenu $menu "$commd" $descr
+    FillMenu $menu $commdargs $descr
     return
 }
 
