@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: gpsinfo.tcl
-#  Last change:  20 October 2004
+#  Last change:  6 April 2006
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -25,7 +25,7 @@
 
 proc DisableGPS {} {
     # change interface appearance when detecting that the receiver went offline
-    global RcW RcMenu GPSState GPSLabel COLOUR TXT RECTYPES SYMBOLIMAGE WConf
+    global RcW RcMenu GPSState GPSLabel COLOUR TXT SYMBOLIMAGE WConf
 
     set GPSState offline ; set GPSLabel $TXT(offline)
     $RcW.frgps.bs.state configure -fg $COLOUR(offline)
@@ -42,8 +42,8 @@ proc DisableGPS {} {
 
 proc EnableGPS {} {
     # change interface appearance when detecting that the receiver went on-line
-    global RcW RcMenu GPSState GPSLabel COLOUR ListInds TXT RECTYPES MYGPS \
-	    SYMBOLIMAGE WConf
+    global RcW RcMenu GPSState GPSLabel COLOUR ListInds TXT RECTYPES RECINFO \
+	MYGPS SYMBOLIMAGE WConf
 
     set GPSState online ; set GPSLabel $TXT(online)
     $RcW.frgps.bs.state configure -fg $COLOUR(online)
@@ -74,6 +74,10 @@ proc EnableGPS {} {
 	    $RcMenu.ptm entryconfigure $WConf(rec,putmn,$i) -state normal
 	}
     }
+    foreach i $RECINFO {
+	$RcW.frget.frget2.get$i configure -state normal
+	$RcMenu.gm entryconfigure $WConf(rec,getmn,$i) -state normal
+    }
     InitGPS
     return
 }
