@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: know.tcl
-#  Last change:  22 October 2004
+#  Last change:  6 April 2006
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -332,7 +332,7 @@ proc NameOf {wh ix} {
 
 proc NewName {wh args} {
     # return an unused valid name for an item of type $wh in $TYPES
-    #  $args may be previous name if $wh==WP
+    #  $args may be the previous name if $wh==WP
     #    that may be used as prefix of new name if formed of acceptable chars
     # in other cases use numbers from 0 with prefix "${wh}-" unless $wh==RT
     global NAMELENGTH MAXROUTES ACCEPTALLCHARS RECNAMECHARS
@@ -340,9 +340,10 @@ proc NewName {wh args} {
     set pre ${wh}- ; set k 0
     switch $wh {
 	WP {
-	    if { $args != "" && \
-		    ($ACCEPTALLCHARS || [CheckName Ignore $args]) } {
-		set pre [string range $args 0 [expr $NAMELENGTH-2]]
+	    set oldname [lindex $args 0]
+	    if { $oldname != "" && \
+		    ($ACCEPTALLCHARS || [CheckName Ignore $oldname]) } {
+		set pre [string range $oldname 0 [expr $NAMELENGTH-3]]
 	    }
 	    if { [set d [expr $NAMELENGTH-[string length $pre]]] > 9 } {
 		set d 9
