@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
 #      along with this program.
 #
 #  File: langdeutsch.tcl
-#  Last change:  22 October 2004
+#  Last change:  8 May 2006
 # German language file by Andreas Lange (Andreas.C.Lange@GMX.de)
 #  last input from him inserted: 31 January 2002
 #
 # Support by Sabine Broda (sbb@ncc.up.pt) since 2002
-#  last input from her inserted:  22 March 2004
+#  last input from her inserted:  8 May 2006
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
 
@@ -290,6 +290,9 @@ array set MESS {
     undefinedTR   "Unbekannter TR"
     emptymenu "Men hat keine Eintragung; fortsetzen?"
     cantwrtsymenu "Kann die nutzerdefinierte Symbolmen Datei nicht schreiben"
+    cantwrtmbaks "Kann die nutzerdefinierte Hintergrund-Datei nicht schreiben"
+    abbrevhasspaces "Abkrzungen drfen keine Leerzeichen haben"
+    getAL "Empfangen des Almanachs"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} Grad {$ALUNIT} Etappe Bezeichnung"
@@ -794,14 +797,14 @@ array set TXT {
     mkavgWP "Mittel-WP erzeugen"
     abbrev "Abkrzung"
     actual "Aktuell"
-    baseproj  "Basisprojektion" ?
+    baseproj "Basisprojektion"
     atprevwp "Vorhergehender WP"
     here "Hier"
     chglstrs "Vorhergehenden Zustand bearbeiten"
     chgnxtrs "Nchsten Zustand bearbeiten"
     contnend "Zum Ende anfgen"
     edmap "In der Karte bearbeiten"
-    prevwp Vorheriger WP"
+    prevwp "Vorheriger WP"
     firstwp "Erster WP"
     fixeddatum  "Festes Datum"
     grid "Gitternetz"
@@ -846,7 +849,6 @@ array set TXT {
     PRJAPOLY "Amerikanische Polykonische"
     computations Berechnungen
     comparea "Berechne Flche"
-    optTRNUMBERINTVL "Zeige TP Nummer auf der Karte alle"
     centre  Mittelpunkt
     mkclusters "Erzeuge Cluster"
     dlat "Wertebereich der Breite"
@@ -1180,6 +1182,30 @@ array set TXT {
     SYcntct_afro "Afro"
     SYcntct_ranger "Ranger"
     numberfrom0 "Zhler auf 1 stellen"
+    fromfile "aus einer Datei"
+    fromdef "von einer Definition"
+    mbaktoload "Zugehriger Hintergrund"
+    none "nichts"
+    opt_Fonts "Schriftgren"
+    optFONTSIZE "Standardschriftgre"
+    optFIXEDFONTSIZE "Monoschriftgre"
+    optICONSIZE "Symbolgre"
+    optTRNUMBERINTVL "Zeige TP Info auf der Karte alle"
+    optTRINFO "zu zeigende TP Info"
+    nameAL "Almanach"
+    alm_svid "Satellitnummer"
+    alm_week "Woche"
+    alm_datatime "Datenreferenzzeit"
+    alm_clockc1 "Taktkorrekturkoeffizient s" 
+    alm_clockc2 "Taktkorrekturkoeffizient s/s" 
+    alm_ecc "Exzentrizitt"
+    alm_sqrta "Quadratwurzel a"
+    alm_mnanom "Mittlere Anomalie"
+    alm_argprgee "Perigumsargument"
+    alm_rightasc "Rektaszension"
+    alm_rtrightasc "Rektaszensionsgeschwindigkeit"
+    alm_inclin "Inklination"
+    alm_health "Gesundheit"
 }
 
     # the following definitions must be coherent with $TXT
