@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  20 October 2004
+#  Last change:  6 April 2006
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au)
@@ -133,6 +133,7 @@ array set MESS {
     getRT   "Getting Routes"
     getTR   "Getting Tracks"
     getLAP  "Getting Laps"
+    getAL   "Getting almanac"
     putWP   "Putting WPoints"
     putRT   "Putting Routes"
     putTR   "Putting Tracks"
@@ -289,6 +290,8 @@ array set MESS {
     lapncnsdrd "LAP not considered"
     emptymenu "Empty menu; continue?"
     cantwrtsymenu "Cannot write symbol menu file"
+    cantwrtmbaks "Cannot write user map backgrounds file"
+    abbrevhasspaces "Short name cannot have blanks"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -334,6 +337,7 @@ array set TXT {
     nameMap   Map
     nameRTComp   "Route Computation"
     nameTRComp   "Track Computation"
+    nameInfo Information
     GPSrec   "GPS receiver"
     turnoff   "Turn Off"
     get   Get
@@ -437,7 +441,8 @@ array set TXT {
     optACCFORMULAE "Accurate formulae"
     optASKPROJPARAMS "Confirm proj parameters"
     optBalloonHelp "Balloon help"
-    optTRNUMBERINTVL "Show TP number on map at each"
+    optTRNUMBERINTVL "Show TP info on map at each"
+    optTRINFO "TP info to show"
     opt_Formats   "Units and formats"
     optDISTUNIT   "Distance"
     optALTUNIT "Altitude"
@@ -495,6 +500,9 @@ array set TXT {
     optMAPCOLOUR,anim  "Animation on map"
     optMAPCOLOUR,emptygrid  "Empty image"
     optMAPCOLOUR,fullgrid   "Existing image"
+    opt_Fonts "Font sizes"
+    optFONTSIZE "Default font size"
+    optFIXEDFONTSIZE "Fixed font size"
     optMAPFONTSIZE "Map font size"
     optDEFTRTWIDTH "RT line width"
     optDEFTTRWIDTH "TR line width"
@@ -507,6 +515,7 @@ array set TXT {
     optPRINTCMD "Print command"
     optPAPERSIZE "Paper size"
     optMapGuideVersion "MapGuide version"
+    optICONSIZE "Icon size"
     red   Red
     green   Green
     blue   Blue
@@ -545,7 +554,9 @@ array set TXT {
     WP   WP
     RT   RT
     TR   TR
+    TP   TP
     LN   LN
+    LP   LP
     GR   GR
     LAP  LAP
     commrec   "Communication with receiver"
@@ -560,7 +571,7 @@ array set TXT {
     savemback "Save geo-ref info"
     chgmback Change
     clearmback Clear
-    backgrnd Backgrnd
+    backgrnd Background
     nameMapBkInfo "Background info"
     nameMapInfo "Map settings"
     mpbkchg "Change background"
@@ -951,6 +962,7 @@ array set TXT {
     animabort "aborting"
     realtimelog "Real-time track log"
     garmin Garmin
+    garmin_usb "Garmin USB"
     nmea "NMEA 0183"
     stext "Simple Text"
     simul "simulator"
@@ -1132,7 +1144,6 @@ array set TXT {
     trvwnopos "Previous positions unavailable"
     trvwuwps "RT has undefined WP(s)"
     trvwchg "Going now to %s"
-    TP TP
     drivesim "driving simulator"
     startfrom "Start from..."
     outofctrl "Out of control!"
@@ -1256,6 +1267,24 @@ array set TXT {
     clssbmn  "Close sub-menu"
     syhlpbx "Use right-button to\nreorder list elements"
     lapsrun Run
+    fromfile "from file"
+    fromdef "from definition"
+    mbaktoload "Background to load"
+    none "none"
+    nameAL "Almanac"
+    alm_svid "satellite id"
+    alm_week "week"
+    alm_datatime "data ref time"
+    alm_clockc1 "clock corr coeff s"
+    alm_clockc2 "clock corr coeff s/s"
+    alm_ecc "eccentricity"
+    alm_sqrta "sqrt a"
+    alm_mnanom "mean anomaly"
+    alm_argprgee "arg perigee"
+    alm_rightasc "right ascension"
+    alm_rtrightasc "rate r ascension"
+    alm_inclin "inclination"
+    alm_health "health"
 }
 
     # the following definitions must be coherent with $TXT
