@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 #      along with this program.
 #
 #  File: langes.tcl
-#  Last change:  20 October 2004
+#  Last change:  12 April 2006
 #
 # Spanish language file by Alberto Morales (amd77@gulic.org)
-#  last input from him: 20 October 2004
+#  last input from him: 8 April 2006
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -280,6 +280,9 @@ array set MESS {
     undefinedTR   "Trayecto desconocido"
     emptymenu "Men vacio; continuar?"
     cantwrtsymenu "No puedo escribir en fichero de men de smbolos"
+    cantwrtmbaks "No puedo escribir fichero de mapas de fondo de usuario"
+    abbrevhasspaces "El nombre corto no puede tener espacios"
+    getAL   "Obteniendo almanaque"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grados {$ALUNIT} etapa etiq"
@@ -423,7 +426,6 @@ array set TXT {
     optACCFORMULAE "Frmulas de mayor precisin"
     optASKPROJPARAMS "Confirmar parmetros de proyeccin"
     optBalloonHelp "Globos de ayuda"
-    optTRNUMBERINTVL "Mostrar nmero en puntos de trayecto cada"
     opt_Formats   "Unidades y formatos"
     optDISTUNIT   "Distancia"
     KM    km
@@ -1223,6 +1225,33 @@ array set TXT {
     duration "Duracin"
     calrs "Caloras"
     getLAP  "Obteniendo Vueltas"
+   fromfile "desde fichero"
+   fromdef "desde definicin"
+   mbaktoload "Fondo para cargar"
+   none "ninguno"
+   opt_Fonts "Tamaos de fuentes"
+   optFONTSIZE "Tamao fuente por defecto"
+   optFIXEDFONTSIZE "Tamao fuente fija"
+   optICONSIZE "Tamao de iconos"
+   LP   PL
+   garmin_usb "Garmin USB"
+   optTRNUMBERINTVL "Mostrar en puntos trayecto en mapa"
+   optTRINFO "Informacin puntos trayecto para mostrar"
+   nameInfo "Informacin"
+   nameAL "Almanaque"
+   alm_svid "id satlite"
+   alm_week "semana"
+   alm_datatime "tiempo ref datos"
+   alm_clockc1 "cpef corr reloj s"
+   alm_clockc2 "coef corr reloj s/s"
+   alm_ecc "excentricidad"
+   alm_sqrta "raiz cuadr a"
+   alm_mnanom "anomala promedio"
+   alm_argprgee "arg perigeo"
+   alm_rightasc "ascensin recta"
+   alm_rtrightasc "veloc ascensin r"
+   alm_inclin "inclinacin"
+   alm_health "salud"
 }
 
     # the following definitions must be coherent with $TXT
@@ -1236,6 +1265,7 @@ array set INVTXT {
     PT   WP
     RT   RT
     TR   TR
+    PL   LP
     LAP  LAP
     GR   GR
 }
