@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  27 October 2004
+#  Last change:  3 May 2006
 #
 # French language file by Valre Robin (valere.robin@wanadoo.fr)
 #  Last change by him:  11 November 2001
@@ -125,6 +125,7 @@ array set MESS {
     getWP   "Acquisition des points d'itinraire"
     getRT   "Acquisition des routes"
     getTR   "Acquisition des traces"
+    getLAP  "Acquisition des tapes"
     putWP   "Chargement des points d'itinraire"
     putRT   "Chargement des routes"
     putTR   "Chargement des traces"
@@ -278,6 +279,9 @@ array set MESS {
     undefinedTR   "TR inconnu"
     emptymenu "Menu vide; continuer?"
     cantwrtsymenu "Impossible d'criture le fichier des menus de symboles"
+    cantwrtmbaks "Impossible d'criture le fichier de fond de carte"
+    abbrevhasspaces "Nom court ne peut pas avoir des blancs"
+    getAL  "Acquisition de l'almanach"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -867,7 +871,6 @@ array set TXT {
     PRJAPOLY "Polyconique amricaine - American Polyconic"
     computations Calculs
     comparea "Calcul de l'aire"
-    optTRNUMBERINTVL "Intervalle pour la numrotation des points sur les traces"
     cluster "Groupement de points"
     mkclusters "Construction de groupements"
     dlat "Intervalle de latitude"
@@ -1212,8 +1215,31 @@ array set TXT {
     optSUPPORTLAPS "Support pour les tapes"
     LAP  ETP
     nameLAP "tape"
-    getLAP  "Acquisition des tapes"
     lapsrun "Course"
+    fromfile "depuis un fichier"
+    fromdef "depuis une dfinition"
+    mbaktoload "Fond de map  charger"
+    none "aucun"
+    opt_Fonts "Tailles des polices"
+    optFONTSIZE "Taille de police dfaut"
+    optFIXEDFONTSIZE "Taille de police fixe"
+    optICONSIZE "Taille des symboles"
+    optTRNUMBERINTVL "Intervalle pour information des points sur les traces"
+    optTRINFO "Information sur point de trace"
+    nameAL "Almanach"
+    alm_svid "identification du satellite"
+    alm_week "semaine"
+    alm_datatime "temps de rfrence"
+    alm_clockc1 "coefficient de correction de l'horloge s"
+    alm_clockc2 "coefficient de correction de l'horloge s/s"
+    alm_ecc "excentricit"
+    alm_sqrta "racine carre de a"
+    alm_mnanom "anomalie moyenne"
+    alm_argprgee "argument du prige"
+    alm_rightasc "ascension droite"
+    alm_rtrightasc "taxe de ascension droite"
+    alm_inclin "inclinaison"
+    alm_health "sant"
 }
 
     # the following definitions must be coherent with $TXT
