@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  21 October 2004
+#  Last change:  12 April 2006
 #  Italian language file by Alessandro Palmas (alpalmas@tin.it)
-#  last input from him inserted:  21 October 2004
+#  last input from him inserted:  12 April 2006
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -123,6 +123,8 @@ array set MESS {
     getWP   "Ricevo WPoints"
     getRT   "Ricevo Rotte"
     getTR   "Ricevo Tracce"
+    getLAP  "Ricezione giri in corso"
+    getAL   "Ricezione almanacco in corso"
     putWP   "Invio WPoints"
     putRT   "Invio Rotte"
     putTR   "Invio Tracce"
@@ -277,6 +279,8 @@ array set MESS {
     undefinedTR   "TR sconosciuta"
     emptymenu "Men vuoto; continuo?"
     cantwrtsymenu "Non posso scrivere il file del men dei simboli"
+    cantwrtmbaks "Impossibile scrivere file mappe background"
+    abbrevhasspaces "I nomi corti non debbono contenere spazi"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg {$ALUNIT} stage label"
@@ -810,7 +814,6 @@ array set TXT {
     PRJAPOLY "Policonica Americana"
     computations Calcolo
     comparea "Calcolo area"
-    optTRNUMBERINTVL "Mostra la numerazione della TP sulla mappa ogni"
     cluster Dintorni
     centre  Centro
     mkclusters "Costruisci dintorni"
@@ -1158,7 +1161,30 @@ array set TXT {
     nameLAP "Giro"
     duration "Tempo"
     calrs "Calorie"
-    getLAP  "Ricezione giri in corso"
+    fromfile "da file"
+    fromdef "da definizione"
+    mbaktoload "Sfondo da caricare"
+    none "nessuno"
+    opt_Fonts "Dimensioni font"
+    optFONTSIZE "Dimensioni default font"
+    optFIXEDFONTSIZE "Dimensione font fissata" 
+    optICONSIZE "Dimensioni icone"
+    optTRNUMBERINTVL "Mostra info TP su mappa ad ogni"
+    optTRINFO "Info TP da mostrare" 
+    nameInfo "Informazioni"
+    nameAL "Almanacco"
+    alm_svid "id satellite"
+    alm_week "settimana"
+    alm_datatime "tempo rif. dati"
+    alm_clockc1 "coeff corr clock s"
+    alm_clockc2 "coeff corr clock s/s"
+    alm_ecc "eccentricit"
+    alm_mnanom "anomalia media"
+    alm_argprgee "arg. perigeo"
+    alm_rightasc "ascensione retta"
+    alm_rtrightasc "var. asc. retta"
+    alm_inclin "inclinazione"
+    alm_health "salute"
 }
 
     # the following definitions must be coherent with $TXT
