@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: lists.tcl
-#  Last change:  22 October 2004
+#  Last change:  31 March 2006
 #
 
 proc ChangeOnStateList {wh st} {
@@ -244,33 +244,6 @@ proc ListDeleteAll {wh} {
     return
 }
 
-proc FillItemsMenu {menu act whit whchg} {
-    # create and fill $menu with items from list
-    #  $act is use as argument to the call-back
-    #  $whit in $TYPES identifies the list
-    #  $whchg either in $TYPES being the type of item that will be modified,
-    #   or matches Search* when proc is used in the search dialog
-    # menus will have continuation sub-menus to keep size <= $MAXMENUITEMS
-    # the callback for each item $it in the menus is
-    #  GM${whchg}Change $act $it
-    global LsW MAXMENUITEMS TXT
-
-    if { [winfo exists $menu] } {
-	$menu delete 0 end
-    } else { menu $menu -tearoff 0 }
-    set n 0 ; set m 0
-    foreach it [$LsW.frl$whit.frl.box get 0 end] {
-	if { $n > $MAXMENUITEMS } {
-	    $menu add cascade -label "$TXT(more) ..." -menu $menu.m$m
-	    set menu $menu.m$m ; destroy $menu ; menu $menu  -tearoff 0
-	    set n 0 ; incr m
-	}
-	$menu add command -label $it -command [list GM${whchg}Change $act $it]
-	incr n
-    }
-    return
-}
-
 proc ChooseItems {wh args} {
     # create modal dialog for selecting from list of items
     #  $wh in $TYPES or LAP
@@ -278,6 +251,7 @@ proc ChooseItems {wh args} {
     #    for a single element, at least one element, and zero or more
     #    elements, and whose tail is a pair that is passed on to
     #    GMChooseFrom and describes parameters
+    # return names of items selected or "" if cancelled
     global LISTWIDTH Storage ListInds TXT
 
     set ids [lindex $Storage($wh) 0]
@@ -294,6 +268,19 @@ proc ChooseItems {wh args} {
 		         $LISTWIDTH $ns $ListInds($wh)]
 }
 
+proc ChItemsCall {wh mode comm args} {
+    # select from list of items and call command
+    #  $wh in $TYPES or LAP
+    #  $mode in {single, many, many_0} as in proc ChooseItems
+    #  $comm is command name to call as
+    #     $comm ARG0 ... ARGn NAMES
+
+    if { [set ixs [ChooseItems $wh $mode]] == "" } { return }
+    set names [Apply $ixs NameOf $wh]
+    eval $comm $args $names
+    return
+}
+
 proc InputToGR {whs notwhs preproc proc postproc fmt} {
     # input data according to contents of group(s)
     # items of types in $whs (except those in $notwhs) will be read in
