@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: main.tcl
-#  Last change: 8 May 2006
+#  Last change:  27 July 2006
 #
 # Includes contributions by
 #  - Brian Baulch (baulchb@onthenet.com.au) marked "BSB contribution"
@@ -26,8 +26,8 @@
 #  - David Gardner (djgardner@users.sourceforge.net) marked "DJG contribution"
 #
 
-set VERSIONDATE(day) 8
-set VERSIONDATE(month) 5
+set VERSIONDATE(day) 27
+set VERSIONDATE(month) 7
 set VERSIONDATE(year) 2006
 
       # these tests here prevent errors in the lang*.tcl files
@@ -137,7 +137,7 @@ if { int($TimeOffset) != $TimeOffset } {
     exit 1
 }
 
-set VERSION 6.3
+set VERSION 6.3.1
 
 set WindowStack ""
 
@@ -201,8 +201,8 @@ $TXT(contrib):\n\
 *   David Gardner (djgardner@users.sourceforge.net)"
 
 
-    grid config $frc.txt -column 0 -row 1 -sticky nesw
-    grid config $frc.tscrl -column 1 -row 1 -sticky nesw
+    grid $frc.txt -column 0 -row 1 -sticky nesw
+    grid $frc.tscrl -column 1 -row 1 -sticky nesw
     pack $w.fr -side top
     pack $w.fr.title $frc -side top -pady 5
     return
@@ -320,7 +320,7 @@ proc GlobalOptionsBindings {} {
 
 proc GMInit {} {
     # set up main window(s)
-    global MAPHEIGHT MAPWIDTH LISTWIDTH LISTHEIGHT COLOUR MAPCOLOUR \
+    global MapHeight MapWidth LISTWIDTH LISTHEIGHT COLOUR MAPCOLOUR \
 	    VERSION SRCDIR LPOSX LPOSY MPOSX MPOSY RPOSX RPOSY \
 	    MAPSCALE MAPDISTS MAPDISTVALS MAPSCLENGTH MWINDOWSCONF TYPES \
 	    RECTYPES MYGPS Temp1 List ListInds EdWindow GPSLabel \
@@ -335,8 +335,8 @@ proc GMInit {} {
 	    FILEFORMAT MapScaleButton MapPFDatum AutoNumRts SUPPORTLAPS \
 	    FixedFont DATUMWIDTH GPSProtocolButton RECINFO
 
-    set MapBounds "0 0 $MAPWIDTH $MAPHEIGHT"
-    set MapRange(x) $MAPWIDTH ; set MapRange(y) $MAPHEIGHT
+    set MapBounds "0 0 $MapWidth $MapHeight"
+    set MapRange(x) $MapWidth ; set MapRange(y) $MapHeight
     set MapRange(x0) 0 ; set MapRange(y0) 0
     set OVx 0 ; set OVy 0 ; set XCoord "" ; set YCoord "" ; set MapZone ""
     set MapWPMoving -1 ; set MapMakingRT 0 ; set MapLoading 0
@@ -501,16 +501,13 @@ proc GMInit {} {
     set Map $MpW.frm.frmap1.map
     canvas $Map -borderwidth 5 -relief groove -confine true \
 	    -scrollregion $MapBounds \
-	    -width $MAPWIDTH -height $MAPHEIGHT \
+	    -width $MapWidth -height $MapHeight \
 	    -xscrollincrement 1 -yscrollincrement 1 \
-	    -xscrollcommand "$MpW.frm.frmap2.mhscr set" \
+	    -xscrollcommand "$MpW.frm.frmap1.mhscr set" \
 	    -yscrollcommand "$MpW.frm.frmap1.mvscr set"
+    bind $Map <Configure> { MapResize }
     scrollbar $MpW.frm.frmap1.mvscr -command "ScrollMap y"
-
-    frame $MpW.frm.frmap2
-    scrollbar $MpW.frm.frmap2.mhscr -command "ScrollMap x" -orient horizontal
-    canvas $MpW.frm.frmap2.fill -height 1 -relief flat \
-	    -width [expr [$MpW.frm.frmap1.mvscr cget -width]+4]
+    scrollbar $MpW.frm.frmap1.mhscr -command "ScrollMap x" -orient horizontal
 
     frame $MpW.frm.frmap3
     # need another frame for the map-main-window layout
@@ -1239,31 +1236,32 @@ proc GMInit {} {
 	grid $fr0
 	pack $MpW.frm.top
     }
-    pack $MpW.frm.frmap1.mvscr -side right -fill y
-    pack $Map -side left -expand yes -fill both
-    pack $MpW.frm.frmap1 -expand yes -fill both
-    pack $MpW.frm.frmap2.mhscr -padx 2 -side left -fill x -expand true
-    pack $MpW.frm.frmap2.fill -side left
-    pack $MpW.frm.frmap2 -pady 0 -fill x -expand true
+    grid $Map -row 0 -column 0 -sticky nesw
+    grid $MpW.frm.frmap1.mvscr -row 0 -column 1 -sticky ns
+    grid $MpW.frm.frmap1.mhscr -row 1 -column 0 -sticky ew
+    grid rowconfigure $MpW.frm.frmap1 0 -weight 1
+    grid columnconfigure $MpW.frm.frmap1 0 -weight 1
 
-    grid config $fr3.cv -row 0 -column 0 -sticky nesw
-    grid config $fr3.mn -row 0 -column 1 -sticky nesw -padx 2
-    grid config $fr3.sep -row 0 -column 2 -sticky nesw -padx 10
-    grid config $fr3.sh -row 0 -column 3 -sticky nesw -padx 5
+    grid $fr3.cv -row 0 -column 0 -sticky nesw
+    grid $fr3.mn -row 0 -column 1 -sticky nesw -padx 2
+    grid $fr3.sep -row 0 -column 2 -sticky nesw -padx 10
+    grid $fr3.sh -row 0 -column 3 -sticky nesw -padx 5
 
     foreach i $ltypes {
 	pack $LsW.frl$i.frl.box $LsW.frl$i.frl.bscr -side left \
-		-fill y -expand true
+		-fill y -expand 1
 	pack $LsW.frl$i.frb.file -side top -pady 5
 	pack $LsW.frl$i.frb $LsW.frl$i.frl -side top \
-		-fill y -expand true
+		-fill y -expand 1
 	pack $LsW.frl$i -side left -fill y
     }
 
     switch $MWINDOWSCONF {
 	lists {
 	    grid $fr3
-	    pack $MpW.frm.frmap3 -pady 2
+	    pack $MpW.frm.frmap3 -pady 2 -side bottom
+	    # must be the last one to be packed under $MpW.frm
+	    pack $MpW.frm.frmap1 -expand 1 -fill both
 
 	    pack $defsmnbt $MpW.frmi.frcoords.transf \
 		    $MpW.frmi.frcoords.ttitle $MpW.frmi.frcoords.proj \
@@ -1279,26 +1277,30 @@ proc GMInit {} {
 	    pack $MpW.frmi.frcoords -side top
 	    pack $MpW.frmi.frmbs -side bottom
 
-	    pack $MpW.frm $MpW.frmi -side left -fill y
+	    pack $MpW.frm -side left -fill y -fill both -expand 1
+	    pack $MpW.frmi -side left -fill y
 	}
 	map {
-	    grid config $fr4.datum -row 0 -column 0 -sticky nesw
-	    grid config $fr4.proj -row 0 -column 1 -sticky nesw -padx 3
-	    grid config $fr4.transf -row 0 -column 2 -sticky nesw -padx 3
+	    grid $fr4.datum -row 0 -column 0 -sticky nesw
+	    grid $fr4.proj -row 0 -column 1 -sticky nesw -padx 3
+	    grid $fr4.transf -row 0 -column 2 -sticky nesw -padx 3
 
-	    grid config $fr5.grid -row 0 -column 0 -sticky nesw
-	    grid config $fr5.zone -row 0 -column 1 -sticky nesw -padx 3
-	    grid config $fr5.xcoord -row 0 -column 2 -sticky nesw -padx 3
-	    grid config $fr5.ycoord -row 0 -column 3 -sticky nesw -padx 3
-	    grid config $fr5.grdat -row 1 -column 0 -columnspan 4 -sticky nesw
+	    grid $fr5.grid -row 0 -column 0 -sticky nesw
+	    grid $fr5.zone -row 0 -column 1 -sticky nesw -padx 3
+	    grid $fr5.xcoord -row 0 -column 2 -sticky nesw -padx 3
+	    grid $fr5.ycoord -row 0 -column 3 -sticky nesw -padx 3
+	    grid $fr5.grdat -row 1 -column 0 -columnspan 4 -sticky nesw
 
-	    grid config $fr3 -row 0 -column 0
-	    grid config $fr4 -row 1 -column 0
-	    grid config $fr5 -row 0 -column 1 -rowspan 2 -padx 10
+	    grid $fr3 -row 0 -column 0
+	    grid $fr4 -row 1 -column 0
+	    grid $fr5 -row 0 -column 1 -rowspan 2 -padx 10
 
-	    pack $MpW.frm.frmap3 -pady 2
-	    pack $MpW.frm
-	    pack $MpW
+	    pack $MpW.frm.frmap3 -pady 2 -side bottom
+	    # must be the last one to be packed under $MpW.frm
+	    pack $MpW.frm.frmap1 -expand 1 -fill both
+
+	    pack $MpW.frm -expand 1 -fill both
+	    pack $MpW -expand 1 -fill both
 
 	    pack .lsw.frbl.frb.load .lsw.frbl.frb.import .lsw.frbl.frb.save \
 		.lsw.frbl.frb.export .lsw.frbl.frb.search -side left -padx 3
@@ -1404,17 +1406,18 @@ proc About {} {
 proc GMStart {} {
     # initialize (most) global variables
     global Index Number Storage File Proc FDDatum \
-	    TYPES PROCTYPES CursorsChanged MAPWIDTH MAPHEIGHT MAPW2 MAPH2 \
-	    AzimuthDegrees MapEmpty DataDefault DataIndex PositionFormat \
-	    DEFAULTSYMBOL DEFAULTDISPOPT Datum EMPTYSTR Anim \
-	    BalloonX BalloonY USERDIR UProjs UFile RealTimeLogOn \
-	    RealTimeLogAnim PVTState USvState USvData USvMap \
-	    BITMAPS SERIALPORT DEFSPORT tcl_platform DEFTRTWIDTH DEFTTRWIDTH \
-	    DEFTLNWIDTH GPSProtocol RECPROTOCOLS GetDispl UNIX MAPCOLOUR \
-	    MapFont MAPFONTSIZE Travelling Travel TRAVELFONTSIZE NAMEWIDTH \
-	    MapMeasure DEFMAPPROJ DEFMAPPFRMT ALTUNIT AltUnit GMEd PlotWNo \
-	    FILEFORMAT DEFTRECPROTOCOL MapPFDatum DEFMAPPFDATUM \
-	    RealTimeGettingFix UDatums UEllipsoids UBackgrnds
+	TYPES PROCTYPES CursorsChanged MapWidth MapHeight MAPW2 MAPH2 \
+	AzimuthDegrees MapEmpty DataDefault DataIndex PositionFormat \
+	DEFAULTSYMBOL DEFAULTDISPOPT Datum EMPTYSTR Anim \
+	BalloonX BalloonY USERDIR UProjs UFile RealTimeLogOn \
+	RealTimeLogAnim PVTState USvState USvData USvMap \
+	BITMAPS SERIALPORT DEFSPORT tcl_platform DEFTRTWIDTH DEFTTRWIDTH \
+	DEFTLNWIDTH GPSProtocol RECPROTOCOLS GetDispl UNIX MAPCOLOUR \
+	MapFont MAPFONTSIZE Travelling Travel TRAVELFONTSIZE NAMEWIDTH \
+	MapMeasure DEFMAPPROJ DEFMAPPFRMT ALTUNIT AltUnit GMEd PlotWNo \
+	FILEFORMAT DEFTRECPROTOCOL MapPFDatum DEFMAPPFDATUM \
+	RealTimeGettingFix UDatums UEllipsoids UBackgrnds \
+	MAPWIDTH MAPHEIGHT
 
     # BSB contribution: globals needed for Lowrance receivers
     global UnusedICInx UnusedWPInx MAX MYGPS
@@ -1651,7 +1654,8 @@ proc GMStart {} {
 
     # map
     set MapEmpty 1 ; set MapMeasure ""
-    set MAPW2 [expr $MAPWIDTH/2.0] ; set MAPH2 [expr $MAPHEIGHT/2.0]
+    set MapWidth $MAPWIDTH ; set MapHeight $MAPHEIGHT
+    set MAPW2 [expr $MapWidth/2.0] ; set MAPH2 [expr $MapHeight/2.0]
     set Anim(number) 0
     foreach x "high medium low" y "important normal info" {
 	set MAPCOLOUR(trvwrn$x) $MAPCOLOUR(trvwrn$y)
