@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: maptransf.tcl
-#  Last change:  13 July 2004
+#  Last change:  17 May 2005
 #
 
 ## Uses information kindly supplied by
@@ -497,7 +497,7 @@ proc MapReduceCPoints {xys} {
     } else {
 	set dd02 [expr 1.0*($y0-$y2)/($x0-$x2)]
 	set dd12 [expr 1.0*($y1-$y2)/($x1-$x2)]
-	set ddm [expr { $dd02 > $dd12 } ? $dd02 : $dd12]
+	set ddm [expr { abs($dd02) > abs($dd12) } ? $dd02 : $dd12]
 	if { abs(($dd02-$dd12)/$ddm) < 0.5 } {
 	    if { abs($x0-$x2) > abs($x1-$x2) } {
 		return [list $ix2 $ix0]
