@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: metadata.tcl
-#  Last change:  16 June 2005
+#  Last change:  25 July 2006
 #
 
 # abstract data used in command-mode, in configuring the graphical interface,
@@ -149,6 +149,12 @@ array set FILEFORMAT {
 	{ expr [lsearch -exact "gps baro" $val]+1 }
 	{/$TXT(alt)|gps baro}
     }
+    Kismet,mode           in
+    Kismet,filetype       unique
+    Kismet,types          WP
+    Kismet,in,params      {group}
+    Kismet,in,pdefts      {0}
+    Kismet,param,group    {GFOption Ignore { expr 1 } {@$TXT(nameGR)}}
     MapGuide,mode         in
     MapGuide,filetype     unique
     MapGuide,types        RT
