@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: navigate.tcl
-#  Last change:  16 September 2004
+#  Last change:  26 May 2005
 #
 
 ##### travel/navigation display
@@ -43,7 +43,7 @@ proc ToTravel {} {
 
 proc TravelInit {fr} {
     # set up the travel frame $fr
-    global Travel RcMenu TXT COLOUR MAPCOLOUR MAPDISTS MAPDISTVALS
+    global Travel RcMenu TXT COLOUR MAPCOLOUR MAPDISTS MAPDISTVALS FontSize
 
     foreach e $Travel(els) { set Travel(info,$e) "" }
     set Travel(info,vel_z) ""
@@ -66,7 +66,7 @@ proc TravelInit {fr} {
     $mn add cascade -label $TXT(startnav) -menu $mn.ms
     menu $mn.ms
     $mn.ms add command -label $TXT(navWP) -command { TravelNav WP }
-    foreach wh "RT TR" {
+    foreach wh "RT TR LN" {
 	$mn.ms add command -label [format $TXT(follow) $TXT($wh)] \
 		-command "TravelNav $wh"
     }
@@ -105,6 +105,12 @@ proc TravelInit {fr} {
 	$mn entryconfigure $ix -label "$TXT(mindist)  $e"
     }
 
+    # prevent bad value for boolean off-road
+    if { $Travel(offroad) != 0 } { set Travel(offroad) 1 }
+    # NOT YET IN USE!
+    # $mn add checkbutton -label $TXT(offroad) -variable Travel(offroad) \
+	    -selectcolor $COLOUR(check)
+
     $mn add command -label $TXT(chginggoal) -command TravelChgGoal
     $mn add cascade -label $TXT(warnings) -menu $mn.mwn
     menu $mn.mwn
@@ -157,7 +163,8 @@ proc TravelInit {fr} {
 	foreach "x y" $ps { lappend psr [expr $cbgw-$x] $y }
 	eval $cbg create polygon $psr -fill $COLOUR(dialbg) -width 1 \
 		-outline black -tags right
-	label $cbg.lab -textvariable Travel(info,trn) -font "fixed 12 bold"
+	label $cbg.lab -textvariable Travel(info,trn) \
+	    -font "fixed $FontSize bold"
 	$cbg create window $cw2 $ch2 -anchor c -window $cbg.lab
 
 	# up-down arrow
@@ -172,7 +179,8 @@ proc TravelInit {fr} {
 		[expr $ch2+2] 2"
 	eval $cvz create polygon $psn -fill $COLOUR(dialbg) -width 1 \
 		-outline black -tags vel_z
-	label $cvz.lab -textvariable Travel(info,vel_z) -font "fixed 14 bold"
+	label $cvz.lab -textvariable Travel(info,vel_z) \
+	    -font "fixed [expr $FontSize+2] bold"
 	$cvz create window [expr 0.75*$cbgw] $ch2 -anchor c -window $cvz.lab
 	set Travel(wdgts,vel_z) [expr 2+$b]
 	set Travel(wdgts,vel_z,up) 1
@@ -613,7 +621,7 @@ proc TravelSUAction {act dsp args} {
 	font {
 	    # if $args is an integer it is the size in points, otherwise
 	    #  the default of Tcl/Tk for the fixed font is used
-	    set Travel(font) [FixedFont $args]
+	    set Travel(font) [GFixedFont $args]
 	    foreach e $Travel(els) {
 		$fr.fri.f$dsp.$e configure -font $Travel(font)
 		$fr.fri.f$dsp.t_$e configure -font $Travel(font)
@@ -837,7 +845,7 @@ proc TravelDoWarn {mess level} {
 
 proc TravelNav {where} {
     # start navigation
-    #  $where in {MOB, WP, RT, TR, GoBack}
+    #  $where in {MOB, WP, RT, TR, LN, GoBack}
     global Travel WConf RealTimeLogOn TXT
 
     if { ! $RealTimeLogOn } {
@@ -864,7 +872,7 @@ proc TravelNav {where} {
 		set ix ""
 	    } else { set ix ok }
 	} else {
-	    # RT, TR
+	    # RT, TR, LN
 	    set ix [ChooseItems $where single \
 		    "Travel(nav,pmode) Travel(nav,pnear) Travel(nav,prvrs)" \
 		    [list "@$TXT(exactly)" "@$TXT(fromnrst)" "@$TXT(inrvrs)"]]
@@ -978,7 +986,7 @@ proc TravelNavToRT {ix} {
 proc TravelNavToTR {ix} {
     # start navigation to TR with given index
     # return 0 on failure
-    global Travel TRTPoints TRDatum TXT MAXWPINROUTE
+    global Travel TRTPoints TRDatum TXT
 
     if { $Travel(nav,pmode) } {
 	set Travel(nav,mode) exact
@@ -986,21 +994,52 @@ proc TravelNavToTR {ix} {
 	set Travel(nav,mode) approx
 	set Travel(nav,nxtleg) ""
     }
-    set ps $TRTPoints($ix) ; set datum $Travel(nav,datum)
-    if { $TRDatum($ix) != $datum } {
-	set ps [ChangeTPsDatum $ps $TRDatum($ix) $datum]
-    }
+    set ps $TRTPoints($ix) ; set trdatum $TRDatum($ix)
+    set datum $Travel(nav,datum)
     set Travel(nav,conv) ""
-    if { $Travel(nav,mode) == "approx" && [llength $ps] > 40 } {
-	# convert to list of at most $MAXWPINROUTE points and follow it
-	set ps [TRCvTR $ps $MAXWPINROUTE $datum travel]
+    if { $Travel(nav,mode) == "approx" && [llength $ps] > 150 } {
+	# convert to list of at most 150 points and follow it
+	set ps [TRCvTR $ps 150 $trdatum travel]
 	set Travel(nav,conv) "*"
     }
+    if { $TRDatum($ix) != $datum } {
+	set ps [ChangeTPsDatum $ps $trdatum $datum]
+    }
     set ps [lindex [TravelNavParams $ps ""] 0]
     TravelNavLine $ps "$TXT(TP) $Travel(nav,conv)0"
     return 1
 }
 
+proc TravelNavToLN {ix} {
+    # start navigation to LN with given index
+    # return 0 on failure
+    global Travel LNLPoints LNDatum TXT
+
+    if { $Travel(nav,pmode) } {
+	set Travel(nav,mode) exact
+    } else {
+	set Travel(nav,mode) approx
+	set Travel(nav,nxtleg) ""
+    }
+    set ps ""
+    foreach lp $LNLPoints($ix) {
+	lappend ps [lindex $lp 0]
+    }
+    set lndatum $LNDatum($ix) ; set datum $Travel(nav,datum)
+    set Travel(nav,conv) ""
+    if { $Travel(nav,mode) == "approx" && [llength $ps] > 150 } {
+	# convert to list of at most 150 points and follow it
+	set ps [TRCvTR $ps 150 $lndatum travel]
+	set Travel(nav,conv) "*"
+    }
+    if { $lndatum != $datum } {
+	set ps [ChangeLPsDatum $ps $lndatum $datum DDD]
+    }
+    set ps [lindex [TravelNavParams $ps ""] 0]
+    TravelNavLine $ps "$TXT(LP) $Travel(nav,conv)0"
+    return 1
+}
+
 proc TravelNavToGoBack {args} {
     # go back using current list of positions
     # follow it exactly, from last position to first ($Travel(posns) is
@@ -1014,7 +1053,7 @@ proc TravelNavToGoBack {args} {
 }
 
 proc TravelNavLine {ps np} {
-    # initialize variables to follow a line (route, track or log)
+    # initialize variables to follow a line (RT, TR, LN or log)
     #  $ps is list of positions
     #  $np is name of next point
     global Travel WConf
@@ -1031,6 +1070,8 @@ proc TravelNavLine {ps np} {
     }
     set Travel(info,prvWP) ""
     set Travel(info,nxtWP) $np
+    # used for TR, LN and GoBack
+    set Travel(ptname) [lindex $np 0]
     return
 }
 
@@ -1449,7 +1490,7 @@ proc TravelData {hms posn lat long fix alt velx vely vel_z trk speed} {
 }
 
 proc TravelChangeGoal {} {
-    # change leg when following RT or TR
+    # change leg when following RT, TR or LN
     # return 1 if there are no more points
     global Travel TXT
 
@@ -1458,9 +1499,9 @@ proc TravelChangeGoal {} {
 	set Travel(info,prvWP) [lindex $Travel(nav,wpns) $tix]
 	set Travel(info,nxtWP) [lindex $Travel(nav,wpns) [incr tix]]
     } else {
-	# TR or GoBack
-	set Travel(info,prvWP) "$TXT(TP) $Travel(nav,conv)$tix"
-	set Travel(info,nxtWP) "$TXT(TP) $Travel(nav,conv)[incr tix]"
+	# TR, LN or GoBack
+	set Travel(info,prvWP) "$Travel(ptname) $Travel(nav,conv)$tix"
+	set Travel(info,nxtWP) "$Travel(ptname) $Travel(nav,conv)[incr tix]"
     }
     # issue change warning
     if { $Travel(nav,towarn) } {
