@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2006 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: posncomp.tcl
-#  Last change:  16 September 2004
+#  Last change:  5 May 2006
 #
 
 ## algorithms and formulae taken or adapted from
@@ -106,9 +106,9 @@ proc DegreesToUTM {lat long datum} {
 	set zn [format "%c" $zn]
 	set long0 [expr 6*int(floor($long/6.0))+3]
 	set ze [format "%02d" [expr int(floor(($long0+183)/6.0))]]
-	set cs [ConvToTM $lat $long $UTMlat0 $long0 $UTMk0 $datum]
-	set x [expr round(5e5+[lindex $cs 0])] ; set y [lindex $cs 1]
-	if { $lat < 0 } { set y [expr int(1e7+$y)] }
+	foreach "x y" [ConvToTM $lat $long $UTMlat0 $long0 $UTMk0 $datum] {}
+	set x [expr 500000+$x]
+	if { $lat < 0 } { set y [expr 10000000+$y] }
     } else {
 	set ze 00
 	if { $lat > 0 } {
@@ -116,8 +116,7 @@ proc DegreesToUTM {lat long datum} {
 	} else {
 	    if { $long < 0 } { set zn A } else { set zn B }
 	}
-	set cs [ConvToUPS $lat $long $datum]
-	set x [lindex $cs 0] ; set y [lindex $cs 1]
+	foreach "x y" [ConvToUPS $lat $long $datum] {}
     }
     return [list $ze $zn $x $y]
 }
@@ -126,8 +125,9 @@ proc UTMToDegrees {ze zn x y datum} {
     # convert from UTM/UPS to lat/long in signed degrees
     global UTMlat0 UTMk0
 
-    if { $ze != 0 } {
-	set long0 [expr -183+6.0*$ze]
+    scan $ze %0d zze
+    if { $zze != 0 } {
+	set long0 [expr -183+6.0*$zze]
 	if { [string compare $zn M] <= 0 } {
 	    set y [expr $y-1e7]
 	}
@@ -314,7 +314,6 @@ proc ConvToUPS {lat long datum} {
     set t [expr tan(0.78539816339744830961-$phi/2)/pow((1-$ee)/(1+$ee),($e/2))]
     set rho [expr 2*$a*$UPSk0*$t/sqrt(pow(1+$e,1+$e)*pow(1-$e,1-$e))]
     set x [expr round($rho*sin($lambda)+2e6)] ; set y [expr $rho*cos($lambda)]
-
     if { $lat > 0 } { set y [expr -$y] }
     return [list $x [expr round($y+2e6)]]
 }
@@ -338,6 +337,8 @@ proc ConvFromUPS {zn x y datum} {
     if { [string compare $zn M] > 0 } {
 	set y [expr -$y]
     }
+    if { $y < 0 } { set long [expr 180-$long] }
+    if { $x < 0 } { set long [expr -$long] }
     return [list $lat $long]
 }
 
