@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2004 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2005 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: realtime.tcl
-#  Last change:  7 October 2004
+#  Last change:  15 June 2005
 #
 
 #### real time logging control
@@ -56,7 +56,7 @@ proc StartRealTimeLog {interval} {
 
     set RealTimeLogIntv $interval
     switch $GPSProtocol {
-	garmin {
+	garmin -  garmin_usb {
 	    if { ! [GarminStartPVT] } { return 0 }
 	}
 	stext {
@@ -95,7 +95,7 @@ proc StopRealTimeLog {} {
     global GPSProtocol RealTimeLogOn RealTimeLogAnim Travelling MYGPS
 
     switch $GPSProtocol {
-	garmin {
+	garmin -  garmin_usb {
 	    GarminStopPVT
 	}
 	lowrance -
@@ -150,7 +150,7 @@ proc UseRealTimeData {data} {
 
     set date [lindex $data 0]
     if { $date == "_" } {
-	if { $GPSProtocol == "garmin" || \
+	if { [string first "garmin" $GPSProtocol] == 0 || \
 		($MYGPS == "Garmin" && $GPSProtocol == "nmea") } {
 	    Log "UPVTD> bad date: $date"
 	}
@@ -219,7 +219,7 @@ proc RealTimeLogWindow {} {
     # columns with empty first values will be collapsed
     global RealTimeLogIntv RealTimeLogAnim DATEWIDTH TXT MPOSX MPOSY COLOUR \
 	    PVTLast PVTState PVTStateExt PVTElapsed PVTZero PVTPosns \
-	    PVTSecs PVTInterval PVTDumping PVTDFile CMDLINE
+	    PVTSecs PVTInterval PVTDumping PVTDFile CMDLINE FixedFont
 
     set PVTLast 0
     set PVTElapsed "" ; set PVTZero -1
@@ -254,7 +254,7 @@ proc RealTimeLogWindow {} {
     foreach b "n d lat long alt fix epe eph epv velx vely velz trk" \
 	    m "5 $DATEWIDTH 10 10 4 4 4 4 4 6 6 6 4" \
 	    t $TXT(PVTflds) {
-	button $fx.tit$b -width $m -text $t -font fixed \
+	button $fx.tit$b -width $m -text $t -font $FixedFont \
 		-command [list CollapseColumn "$fx.tit$b $fx.bx$b" $col \
 		                               $t menubtentry $mn $show]
 	BalloonBindings $fx.tit$b hide
@@ -419,12 +419,12 @@ proc RTimeStateChange {n no op} {
 
 proc RTimeIntervalChange {n no op} {
     # called by trace when $PVTInterval has been changed
-    # if there is an animation window for the log set AnimSpeed(-1)
+    # if there is an animation window for the log set Anim(speed,-1)
     #  that has a trace on it; otherwise set RealTimeLogIntv directly
-    global PVTInterval RealTimeLogIntv AnimState
+    global PVTInterval RealTimeLogIntv Anim
 
     if { [winfo exists .anim-1] } {
-	after 0 "set AnimSpeed(-1) [expr $PVTInterval-51]"
+	after 0 "set Anim(speed,-1) [expr $PVTInterval-51]"
     } else {
 	set RealTimeLogIntv $PVTInterval
     }
